@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -17,14 +17,16 @@
  *************************************************************************************/
 
 #include "expressiontest.h"
-#include "analitza.h"
+#include "analyzer.h"
 #include "explexer.h"
 #include "expressionparser.h"
 
 #include <qtest_kde.h>
 #include <cmath>
+#include <analitzautils.h>
 
 using namespace std;
+using Analitza::Expression;
 
 QTEST_KDEMAIN_CORE( ExpressionTest )
 
@@ -45,7 +47,7 @@ void ExpressionTest::cleanupTestCase()
 	delete e;
 }
 
-QString removeTags(const QString& in)
+static QString removeTags(const QString& in)
 {
 	bool tag=false;
 	QString out;
@@ -72,14 +74,21 @@ void ExpressionTest::testConversion_data()
 	QTest::newRow("addition") << "2+4";
 	QTest::newRow("addition with var") << "2+x";
 	QTest::newRow("function definition") << "f:=x->x+1";
-	QTest::newRow("simple addition and subtraction") << "2+x-3";
-	QTest::newRow("simple addition and unary minus") << "(-x)+y";
+	QTest::newRow("simple addition and subtraction") << "(2+x)-3";
+	QTest::newRow("simple addition and unary minus") << "-x+y";
+	QTest::newRow("minusplus") << "-(x+y)";
+	QTest::newRow("minuspower") << "-x^2";
 	QTest::newRow("sum") << "sum(x^2:x=1..10)";
 	QTest::newRow("piecewise") << "piecewise { x ? y, ? 33 }";
 	QTest::newRow("function call") << "f(2)";
 	QTest::newRow("vector") << "vector { x, y, z }";
-	QTest::newRow("boundedlambda") << "q=0..10->q";
 	QTest::newRow("bounded") << "diff(x^2:x)";
+	QTest::newRow("lambda call") << "(x->x+2)(2)";
+	QTest::newRow("lambda call") << "(selector(f, 1))(2)";
+	QTest::newRow("eq") << "2=2";
+	QTest::newRow("vector") << "vector { 1, 2, 3 }";
+	QTest::newRow("list") << "list {  }";
+	QTest::newRow("listbvar") << "sum(p:x@mylist)";
 }
 
 void ExpressionTest::testConversion()
@@ -94,8 +103,12 @@ void ExpressionTest::testConversion()
 		qDebug() << ">>> " << parser.mathML() << "errors:" << parser.error();
 	QVERIFY(corr);
 	QVERIFY(parser.error().isEmpty());
+// 	qDebug() << "result:" << parser.mathML();
 	
 	e->setMathML(parser.mathML());
+	if(!e->isCorrect())
+		qDebug() << "semantic errors: " << e->error();
+	
 	QVERIFY(e->isCorrect());
 	QCOMPARE(e->toString(), input);
 	QCOMPARE(removeTags(e->toHtml()), input);
@@ -109,9 +122,16 @@ void ExpressionTest::testCopy_data()
 	QTest::newRow("simple addition") << "2+4";
 	QTest::newRow("simple addition with var") << "2+x";
 	QTest::newRow("function definition") << "f:=x->x+1";
+	QTest::newRow("function call") << "f(x, y)";
 	QTest::newRow("summatory") << "sum(x:x=1..10)";
 	QTest::newRow("conditional") << "piecewise { x ? y, ? 33 }";
 	QTest::newRow("vector") << "vector { x, y, z }";
+	
+	QTest::newRow("simple addition") << "2+4";
+	QTest::newRow("simple addition with var") << "2+x";
+	QTest::newRow("functin definition") << "f:=x->x+1";
+	QTest::newRow("summatory") << "sum(x:x=1..10)";
+	QTest::newRow("conditional") << "piecewise { x ? y, ? 33 }";
 }
 
 void ExpressionTest::testCopy()
@@ -122,55 +142,63 @@ void ExpressionTest::testCopy()
 	Expression e2(*e);
 	QVERIFY(e->isCorrect() && e2.isCorrect());
 	QCOMPARE(*e, e2);
+	QCOMPARE(e->toString(), input);
 	QCOMPARE(removeTags(e->toHtml()), input);
 }
 
-void ExpressionTest::testCorrection_data()
+void ExpressionTest::testUncorrection_data()
 {
 	QTest::addColumn<QString>("input");
-	QTest::addColumn<bool>("isCorrect");
 	
-	QTest::newRow("simple addition") << "2+4" << true;
-	QTest::newRow("simple addition with var") << "2+x" << true;
-	QTest::newRow("functin definition") << "f:=x->x+1" << true;
-	QTest::newRow("summatory") << "sum(x : x=1..10)" << true;
-	QTest::newRow("conditional") << "piecewise { x ? y, ? 33 }" << true;
-	QTest::newRow("conditional") << "sum(n*x : n=1..10)" << true;
+	QTest::newRow("incorrect bounds") << "product(x,1:3)";
 	
-	QTest::newRow("addition with missing operand") << "2+" << false;
-	QTest::newRow("function definition") << "f:=n->" << false;
-	QTest::newRow("piecewise") << "piecewise { ?3, 2 }" << false;
+	QTest::newRow("addition with missing operand") << "2+";
+	QTest::newRow("function definition") << "f:=n->";
+	QTest::newRow("piecewise") << "piecewise { ?3, 2 }";
 	
-	QTest::newRow("limits") << "f:=n->3.." << false;
-	QTest::newRow("summatory with unknown uplimit") << "sum(x=1.. : x)" << false;
+	QTest::newRow("limits") << "f:=n->3..";
+	QTest::newRow("summatory with unknown uplimit") << "sum(x=1.. : x)";
 	//FIXME: Should be false in runtime, controlling it on the compiler.
 	//There is no way to have uplimit/downlimit separatedly with the current Exp parser
 	
-	QTest::newRow("uncotextualized bounds") << "9..99" << false;
-	QTest::newRow("uncotextualized bounds") << "9..(9+9)" << false;
-	QTest::newRow("uncotextualized bounds") << "x:=9..(9+9)" << false;
-	QTest::newRow("uncotextualized bounds") << "3+(9..(9+9))" << false;
-	QTest::newRow("uncotextualized bounds") << "3+9..(9+9)" << false;
-	QTest::newRow("missing )") << "(" << false;
-	QTest::newRow("missing }") << "vector{" << false;
+	QTest::newRow("uncotextualized bounds") << "9..99";
+	QTest::newRow("uncotextualized bounds") << "9..(9+9)";
+	QTest::newRow("uncotextualized bounds") << "x:=9..(9+9)";
+	QTest::newRow("uncotextualized bounds") << "3+(9..(9+9))";
+	QTest::newRow("uncotextualized bounds") << "3+9..(9+9)";
+	QTest::newRow("missing )") << "(";
+	QTest::newRow("missing }") << "vector{";
+	QTest::newRow("wrong piecewise") << "piecewise { 0 ? 0 ? 0 }";
+	QTest::newRow("vector piece") << "vector { 0 ? 0 }";
+	QTest::newRow("wrong assignation") << "2:=3";
+	QTest::newRow("non-condition in piecewise") << "piecewise{ 2, ?3 }";
+	QTest::newRow("not-a-container") << "or{ x }";
+	QTest::newRow("different tag") << "prp { x, y, z }";
+	QTest::newRow("different tag") << "a+a=10..";
+	QTest::newRow("xxx") << "piecewise {scalarproduct(vector{x, 1/x})}";
+	QTest::newRow("wrong piece") << "plus(piece{2+2}, 1,2,3)";
+	QTest::newRow("wrong sum") << "sum(x : x)";
+	QTest::newRow("nopiece") << "fib:=n->piecewise { eq(n,0)?0, eq(n,1)?1, fib(n-1)+fib(n-2) }";
+	QTest::newRow("wrong count") << "plus(1)";
+	QTest::newRow("wrong parameters") << "selector(vector{1,1/3})";
+	QTest::newRow("empty vector") << "vector{}";
+	
+	QTest::newRow("same args") << "(x,x)->x";
+	QTest::newRow("same boundings") << "sum(x : (x,x)=1..10)";
 }
 
-void ExpressionTest::testCorrection()
+void ExpressionTest::testUncorrection()
 {
 	QFETCH(QString, input);
-	QFETCH(bool, isCorrect);
 	for(int i=0; i<input.length(); i++)
-	{
 		e->setText(input.mid(0, i));
-	}
+	
 	e->setText(input);
-	QCOMPARE(e->isCorrect(), isCorrect);
-	QVERIFY(e->error().isEmpty()==isCorrect);
-	foreach(const QString& s, e->error()) {
-		QVERIFY(!s.isEmpty());
-		if(s.isEmpty())
-			qDebug() << e->error();
-	}
+	
+	QVERIFY(!e->isCorrect());
+	QVERIFY(!e->error().isEmpty());
+	
+	QVERIFY(!e->error().contains(QString()));
 }
 
 #include "expressiontest.moc"
