@@ -43,6 +43,7 @@
 #include <kmessagebox.h>
 
 #include <map>
+#include <iterator>
 
 // we need this for storing colors in a std::map..
 static bool operator<( const QColor& a, const QColor& b )
@@ -476,6 +477,13 @@ void XFigExportImpVisitor::visit( const FilledPolygonImp* imp )
       mstream << "\n";
 }
 
+void XFigExportImpVisitor::visit(const ClosedPolygonalImp* imp)
+{
+}
+void XFigExportImpVisitor::visit(const OpenPolygonalImp* imp)
+{
+}
+
 void XFigExporter::run( const KigPart& doc, KigWidget& w )
 {
   KigFileDialog* kfd = new KigFileDialog(
