@@ -1,9 +1,8 @@
 /*
 * KmPlot - a math. function plotter for the KDE-Desktop
 *
-* Copyright (C) 2004  Fredrik Edemar
-*                     f_edemar@linux.se
-*               
+* Copyright (C) 2004  Fredrik Edemar <f_edemar@linux.se>
+*
 * This file is part of the KDE Project.
 * KmPlot is part of the KDE-EDU Project.
 *
@@ -11,12 +10,12 @@
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
-* 
+*
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -28,39 +27,45 @@
 #include <kaction.h>
 #include <kconfig.h>
 #include <kedittoolbar.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <kfiledialog.h>
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kmplotprogress.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kurl.h>
+#include <kactioncollection.h>
+#include "maindlg.h"
+#include <ktoolinvocation.h>
+#include <ktogglefullscreenaction.h>
+#include <kapplication.h>
 
-#include "MainDlg.h"
-#include "kmplotprogress.h"
+#include "kmplotadaptor.h"
 
 KmPlot::KmPlot( KCmdLineArgs* args)
-		: DCOPObject( "KmPlotShell" ), KParts::MainWindow( 0L, "KmPlot" )
+		: KParts::MainWindow()
 {
+	setObjectName( "KmPlot" );
+
 	// set the shell's ui resource file
 	setXMLFile("kmplot_shell.rc");
 	// then, setup our actions
 	setupActions();
-	
+
 	// setup the status bar
 	setupStatusBar();
-	
+
 	// this routine will find and load our Part.  it finds the Part by
 	// name which is a bad idea usually.. but it's alright in this
 	// case since our Part is made for this Shell
-	KLibFactory *factory = KLibLoader::self()->factory("libkmplotpart");
+    KPluginFactory *factory = KPluginLoader("libkmplotpart").factory();
 	if (factory)
 	{
 		// now that the Part is loaded, we cast it to a Part to get
 		// our hands on it
-		m_part = static_cast<KParts::ReadOnlyPart *>(factory->create(this,
-		         "kmplot_part", "KParts::ReadOnlyPart" ));
+        m_part = factory->create<KParts::ReadWritePart>(this);
 		if (m_part)
 		{
 			// tell the KParts::MainWindow that this is indeed the main widget
@@ -75,14 +80,14 @@ KmPlot::KmPlot( KCmdLineArgs* args)
 		// if we couldn't find our Part, we exit since the Shell by
 		// itself can't do anything useful
 		KMessageBox::error(this, i18n("Could not find KmPlot's part."));
-		kapp->quit();
-		// we return here, cause kapp->quit() only means "exit the
+		qApp->quit();
+		// we return here, cause qApp->quit() only means "exit the
 		// next time we enter the event loop...
 		return;
 	}
 
 	if (!initialGeometrySet())
-		resize( QSize(450, 520).expandedTo(minimumSizeHint()));
+		resize( QSize(800, 520).expandedTo(minimumSizeHint()));
 
 	// apply the saved mainwindow settings, if any, and ask the mainwindow
 	// to automatically save settings if changed: window size, toolbar
@@ -101,10 +106,22 @@ KmPlot::KmPlot( KCmdLineArgs* args)
 			else
 				openFileInNewWindow( args->url(i) );
 		}
-		args->clear();
 		if (exit)
 			deleteLater(); // couln't open the file, and therefore exit
 	}
+
+	show();
+
+    new KmPlotAdaptor(this);
+    QDBusConnection::sessionBus().registerObject("/kmplot", this);
+
+    if ( args && args->isSet("function") )
+    {
+        QString f = args->getOption("function");
+        QDBusReply<bool> reply = QDBusInterface( QDBusConnection::sessionBus().baseService(), "/parser", "org.kde.kmplot.Parser").call( QDBus::BlockWithGui, "addFunction", f, "" );
+    }
+    if( args )
+	args->clear();
 }
 
 KmPlot::~KmPlot()
@@ -114,56 +131,42 @@ void KmPlot::slotUpdateFullScreen( bool checked)
 {
 	if (checked)
 	{
-		showFullScreen();
-		m_fullScreen->plug( toolBar( "mainToolBar" ) );
+		KToggleFullScreenAction::setFullScreen( this, true );
+		//m_fullScreen->plug( toolBar( "mainToolBar" ) ); deprecated annma 2006-03-01
 	}
 	else
 	{
-		showNormal();
-		m_fullScreen->unplug( toolBar( "mainToolBar" ) );
+		KToggleFullScreenAction::setFullScreen( this, false );
+		//m_fullScreen->unplug( toolBar( "mainToolBar" ) ); deprecated annma 2006-03-01
 	}
 }
 
-bool KmPlot::load(const KURL& url)
+bool KmPlot::load(const KUrl& url)
 {
-	m_part->openURL( url );
+	m_part->openUrl( url );
   if (m_part->url().isEmpty())
     return false;
-  setCaption(url.prettyURL(0, KURL::StripFileProtocol));
+  setCaption(url.prettyUrl(KUrl::LeaveTrailingSlash));
   return true;
 }
 
 void KmPlot::setupActions()
 {
-	KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
-	KStdAction::open(this, SLOT(fileOpen()), actionCollection());
-	KStdAction::quit(kapp, SLOT(quit()), actionCollection());
+	KStandardAction::openNew(this, SLOT(fileNew()), actionCollection());
+	KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
+	KStandardAction::quit(kapp, SLOT(quit()), actionCollection());
 
 	createStandardStatusBarAction();
 	setStandardToolBarMenuEnabled(true);
-	
-	KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
-	KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
 
-	m_fullScreen = KStdAction::fullScreen( NULL, NULL, actionCollection(), this, "fullscreen");
+	KStandardAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
+	KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
+
+	m_fullScreen = KStandardAction::fullScreen( NULL, NULL, this, actionCollection());
+	actionCollection()->addAction("fullscreen", m_fullScreen);
 	connect( m_fullScreen, SIGNAL( toggled( bool )), this, SLOT( slotUpdateFullScreen( bool )));
 }
 
-void KmPlot::saveProperties(KConfig* /*config*/)
-{
-	// the 'config' object points to the session managed
-	// config file.  anything you write here will be available
-	// later when this app is restored
-}
-
-void KmPlot::readProperties(KConfig* /*config*/)
-{
-	// the 'config' object points to the session managed
-	// config file.  this function is automatically called whenever
-	// the app is being restored.  read in here whatever you wrote
-	// in 'saveProperties'
-}
-
 void KmPlot::fileNew()
 {
 	// About this function, the style guide (
@@ -171,52 +174,30 @@ void KmPlot::fileNew()
 	// says that it should open a new window if the document is _not_
 	// in its initial state.  This is what we do here..
 	if ( !m_part->url().isEmpty() || isModified() )
-		//KApplication::startServiceByDesktopName("kmplot");
-		KApplication::kdeinitExec("kmplot");
+		//KToolInvocation::startServiceByDesktopName("kmplot");
+		KToolInvocation::kdeinitExec("kmplot");
 }
 
-bool KmPlot::stopProgressBar()
-{
-	if (m_progressbar && m_progressbar->isShown())
-	{
-		m_progressbar->hide();
-		return true;
-	}
-	return false;
-}
-
-void KmPlot::startProgressBar(int steps)
-{
-	if (m_progressbar)
-	{
-		m_progressbar->progress->setTotalSteps(steps);
-		m_progressbar->show();
-	}
-}
-
-void KmPlot::increaseProgressBar()
-{
-	if (m_progressbar)
-		m_progressbar->increase();
-}
 
 void KmPlot::optionsConfigureKeys()
 {
-	KKeyDialog::configure(actionCollection(), "kmplot_shell.rc");
+	/// \todo check that configuring keys works
+// 	KShortcutsDialog::configure(actionCollection(), "kmplot_shell.rc");
+	KShortcutsDialog::configure( actionCollection() );
 }
 
 void KmPlot::optionsConfigureToolbars()
 {
-	saveMainWindowSettings(KGlobal::config() );
+	saveMainWindowSettings( KGlobal::config()->group( QString() ));
 	// use the standard toolbar editor
-	KEditToolbar dlg(factory());
-	connect(&dlg, SIGNAL(newToolbarConfig()), this, SLOT(applyNewToolbarConfig()));
+	KEditToolBar dlg(factory());
+	connect(&dlg, SIGNAL(newToolBarConfig()), this, SLOT(applyNewToolbarConfig()));
 	dlg.exec();
 }
 
 void KmPlot::applyNewToolbarConfig()
 {
-	applyMainWindowSettings(KGlobal::config());
+	applyMainWindowSettings(KGlobal::config()->group( QString() ));
 }
 
 void KmPlot::fileOpen()
@@ -224,8 +205,8 @@ void KmPlot::fileOpen()
 	// this slot is called whenever the File->Open menu is selected,
 	// the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
 	// button is clicked
-	KURL const url = KFileDialog::getOpenURL( QDir::currentDirPath(),
-	                 i18n( "*.fkt|KmPlot Files (*.fkt)\n*.*|All Files" ), this, i18n( "Open" ) );
+	KUrl const url = KFileDialog::getOpenUrl( QDir::currentPath(),
+	                 i18n( "*.fkt|KmPlot Files (*.fkt)\n*|All Files" ), this, i18n( "Open" ) );
 
 	if ( !url.isEmpty())
 	{
@@ -240,7 +221,7 @@ void KmPlot::fileOpen()
 	}
 }
 
-void KmPlot::fileOpen(const KURL &url)
+void KmPlot::fileOpen(const KUrl &url)
 {
 	if ( !url.isEmpty())
 	{
@@ -252,67 +233,59 @@ void KmPlot::fileOpen(const KURL &url)
          load( KStandardDirs::realFilePath(url.url())); // we open the file in this window...
 		else
          openFileInNewWindow(url); // we open the file in a new window...
-	}	
+	}
 }
 
 
-void KmPlot::openFileInNewWindow(const KURL url)
+void KmPlot::openFileInNewWindow(const KUrl &url)
 {
- KApplication::startServiceByDesktopName("kmplot",url.url());
-}
-
-bool KmPlot::checkModified()
-{
-	QCString replyType;
-	QByteArray replyData;
-	kapp->dcopClient()->call(kapp->dcopClient()->appId(), "MainDlg","checkModified()", QByteArray(), replyType, replyData, false);
-	bool result;
-	QDataStream stream(replyData, IO_ReadOnly);
-	stream >> result;
-	return result;
+ KToolInvocation::startServiceByDesktopName("kmplot",url.url());
 }
 
 bool KmPlot::isModified()
 {
-	QCString replyType;
-	QByteArray replyData;
-	kapp->dcopClient()->call(kapp->dcopClient()->appId(), "MainDlg","isModified()", QByteArray(), replyType, replyData, false);
-	bool result;
-	QDataStream stream(replyData, IO_ReadOnly);
-	stream >> result;
-	return result;
+	QDBusReply<bool> reply = QDBusInterface( QDBusConnection::sessionBus().baseService(), "/maindlg", "org.kde.kmplot.MainDlg").call( QDBus::BlockWithGui, "isModified" );
+    return reply.value();
 }
 
 bool KmPlot::queryClose()
 {
-	return checkModified();
+	return m_part->queryClose();
 }
 
 void KmPlot::setStatusBarText(const QString &text, int id)
 {
-	statusBar()->changeItem(text,id);
+ 	statusBar()->changeItem(text,id);
 }
 
 
 void KmPlot::setupStatusBar()
 {
-	statusBar()->insertFixedItem( "1234567890", 1 );
-	statusBar()->insertFixedItem( "1234567890", 2 );
+	statusBar()->insertFixedItem( "1234567890123456", 1 );
+	statusBar()->insertFixedItem( "1234567890123456", 2 );
 	statusBar()->insertItem( "", 3, 3 );
 	statusBar()->insertItem( "", 4 );
 	statusBar()->changeItem( "", 1 );
 	statusBar()->changeItem( "", 2 );
-	statusBar()->setItemAlignment( 3, AlignLeft );
+	statusBar()->setItemAlignment( 3, Qt::AlignLeft );
 
-	m_progressbar = new KmPlotProgress( statusBar() );
-	m_progressbar->setMaximumHeight( statusBar()->height()-10 );
-	connect( m_progressbar->button, SIGNAL (clicked() ), this, SLOT( progressbar_clicked() ) );
-	statusBar()->addWidget(m_progressbar);
+	m_progressBar = new KmPlotProgress( statusBar() );
+	m_progressBar->setMaximumHeight( statusBar()->height()-10 );
+	connect( m_progressBar, SIGNAL (cancelDraw() ), this, SLOT( cancelDraw() ) );
+	statusBar()->addWidget(m_progressBar);
 }
 
-void KmPlot::progressbar_clicked()
+
+void KmPlot::setDrawProgress( double progress )
 {
-	kapp->dcopClient()->send(kapp->dcopClient()->appId(), "View","stopDrawing()", QByteArray());
+	m_progressBar->setProgress( progress );
 }
 
+
+void KmPlot::cancelDraw()
+{
+	QDBusInterface( QDBusConnection::sessionBus().baseService(), "/kmplot", "org.kde.kmplot.KmPlot" ).call( QDBus::NoBlock, "stopDrawing" );
+}
+
+
 #include "kmplot.moc"
