@@ -31,7 +31,7 @@
 #include <ktoggleaction.h>
 #include <ktoolbar.h>
 #include <kicon.h>
-#include <knewstuff2/ui/knewstuffaction.h>
+#include <knewstuff3/knewstuffaction.h>
 
 #include "Options.h"
 #include "fov.h"
@@ -44,6 +44,7 @@
 #include "widgets/timestepbox.h"
 #include "comast/equipmentwriter.h"
 #include "comast/observeradd.h"
+#include "skycomponents/skymapcomposite.h"
 
 #include <config-kstars.h>
 
@@ -128,7 +129,7 @@ void KStars::initActions() {
     KAction *ka;
 
     // ==== File menu ================
-    ka = KNS::standardAction(i18n("Download New Data..."), this, SLOT(slotDownload()), actionCollection(), "get_data")
+    ka = KNS3::standardAction(i18n("Download New Data..."), this, SLOT(slotDownload()), actionCollection(), "get_data")
         << KShortcut( Qt::CTRL+Qt::Key_D );
     ka->setWhatsThis(i18n("Downloads new data"));
     ka->setToolTip(ka->whatsThis());
@@ -200,9 +201,9 @@ void KStars::initActions() {
         << KShortcut( Qt::CTRL+Qt::Key_M );
 
     // ==== View Menu ================
-    actionCollection()->addAction( KStandardAction::ZoomIn,  "zoom_in", this, SLOT( zoomIn() ) );
-    actionCollection()->addAction( KStandardAction::ZoomOut, "zoom_out", this, SLOT( zoomOut() ) );
-    actionCollection()->addAction("zoom_default", this, SLOT( defaultZoom() ) )
+    actionCollection()->addAction( KStandardAction::ZoomIn,  "zoom_in",  map(), SLOT( slotZoomIn() ) );
+    actionCollection()->addAction( KStandardAction::ZoomOut, "zoom_out", map(), SLOT( slotZoomOut() ) );
+    actionCollection()->addAction("zoom_default", map(), SLOT( slotZoomDefault() ) )
         << i18n("&Default Zoom")
         << KIcon("zoom-fit-best" )
         << KShortcut( Qt::CTRL+Qt::Key_Z );
@@ -253,25 +254,36 @@ void KStars::initActions() {
     KAction* kaBoxes = actionCollection()->add<KToggleAction>("show_boxes" )
         << i18nc("Show the information boxes", "Show &Info Boxes")
         << Checked( Options::showInfoBoxes() );
+    connect( kaBoxes, SIGNAL(toggled(bool)), map(), SLOT(slotToggleInfoboxes(bool)));
+    kaBoxes->setChecked( Options::showInfoBoxes() );
 
     ka = actionCollection()->add<KToggleAction>("show_time_box")
         << i18nc("Show time-related info box", "Show &Time Box");
-    connect(kaBoxes, SIGNAL( toggled(bool) ), ka, SLOT( setEnabled(bool) ) );
+    connect(kaBoxes, SIGNAL( toggled(bool) ), ka,    SLOT( setEnabled(bool) ) );
+    connect(ka,      SIGNAL( toggled(bool) ), map(), SLOT( slotToggleTimeBox(bool)));
+    ka->setChecked( Options::showTimeBox() );
+    ka->setEnabled( Options::showInfoBoxes() );
 
     ka = actionCollection()->add<KToggleAction>("show_focus_box")
         << i18nc("Show focus-related info box", "Show &Focus Box");
-    connect(kaBoxes, SIGNAL( toggled(bool) ), ka, SLOT( setEnabled(bool) ) );
+    connect(kaBoxes, SIGNAL( toggled(bool) ), ka,    SLOT( setEnabled(bool) ) );
+    connect(ka,      SIGNAL( toggled(bool) ), map(), SLOT( slotToggleFocusBox(bool)));
+    ka->setChecked( Options::showFocusBox() );
+    ka->setEnabled( Options::showInfoBoxes() );
 
     ka = actionCollection()->add<KToggleAction>("show_location_box")
         << i18nc("Show location-related info box", "Show &Location Box");
-    connect(kaBoxes, SIGNAL( toggled(bool) ), ka, SLOT( setEnabled(bool) ) );
+    connect(kaBoxes, SIGNAL( toggled(bool) ), ka,    SLOT( setEnabled(bool) ) );
+    connect(ka,      SIGNAL( toggled(bool) ), map(), SLOT( slotToggleGeoBox(bool)));
+    ka->setChecked( Options::showGeoBox() );
+    ka->setEnabled( Options::showInfoBoxes() );
 
 
     //Toolbar options
     newToggleAction( actionCollection(), "show_mainToolBar", i18n("Show Main Toolbar"),
-                     this, SLOT(slotShowGUIItem(bool)));
+                     toolBar("kstarsToolBar"), SLOT(setVisible(bool)));
     newToggleAction( actionCollection(), "show_viewToolBar", i18n("Show View Toolbar"),
-                     this, SLOT(slotShowGUIItem(bool)));
+                     toolBar( "viewToolBar" ), SLOT(setVisible(bool)));
 
     //Statusbar view options
     newToggleAction( actionCollection(), "show_statusBar", i18n("Show Statusbar"),
@@ -609,7 +621,7 @@ void KStars::initFocus() {
 
     //Check whether initial position is below the horizon.
     if ( Options::useAltAz() && Options::showHorizon() && Options::showGround() &&
-            map()->focus()->alt()->Degrees() < -1.0 ) {
+            map()->focus()->alt().Degrees() < -1.0 ) {
         QString caption = i18n( "Initial Position is Below Horizon" );
         QString message = i18n( "The initial position is below the horizon.\nWould you like to reset to the default position?" );
         if ( KMessageBox::warningYesNo( this, message, caption,
@@ -637,16 +649,16 @@ void KStars::initFocus() {
 }
 
 void KStars::buildGUI() {
+    //create the skymap
+    skymap = SkyMap::Create();
+    connect(skymap, SIGNAL(mousePointChanged(SkyPoint*)), SLOT(slotShowPositionBar(SkyPoint*)));
+    connect(skymap, SIGNAL(zoomChanged()),                SLOT(slotZoomChanged()));
+    setCentralWidget( skymap );
+
     //Initialize menus, toolbars, and statusbars
     initStatusBar();
     initActions();
 
-    //create the skymap
-    skymap = SkyMap::Create();
-    setCentralWidget( skymap );
-    connect(skymap, SIGNAL(zoomChanged()), this, SLOT( slotZoomChanged() ));
-
-
     setupGUI(StandardWindowOptions (Default & ~Create));
 
 #ifdef Q_WS_WIN
