@@ -18,52 +18,44 @@
 #include "altvstime.h"
 
 #include <QVBoxLayout>
-#include <QPainter>
-#include <QMouseEvent>
-#include <QPixmap>
 #include <QFrame>
-#include <QPaintEvent>
-#include <QPointF>
 
 #include <klocale.h>
-#include <klineedit.h>
-#include <kpushbutton.h>
 #include <kdialog.h>
 #include <kplotobject.h>
-#include <kplotaxis.h>
 #include <kplotwidget.h>
+#include <kplotaxis.h>
 
-#include "ui_altvstime.h"
 #include "dms.h"
-#include "kstars.h"
+#include "ksalmanac.h"
 #include "kstarsdata.h"
-#include "skyobjects/skypoint.h"
-#include "skyobjects/skyobject.h"
+#include "kstarsdatetime.h"
 #include "ksnumbers.h"
 #include "simclock.h"
 #include "dialogs/finddialog.h"
 #include "dialogs/locationdialog.h"
-#include "widgets/dmsbox.h"
+#include "skyobjects/skypoint.h"
+#include "skyobjects/skyobject.h"
+
 #include "avtplotwidget.h"
+#include "ui_altvstime.h"
 
-#include "kstarsdatetime.h"
-
-AltVsTimeUI::AltVsTimeUI( QWidget *p ) : QFrame( p ) {
+AltVsTimeUI::AltVsTimeUI( QWidget *p ) :
+    QFrame( p )
+{
     setupUi( this );
 }
 
 AltVsTime::AltVsTime( QWidget* parent)  :
-        KDialog( parent )
+    KDialog( parent )
 {
-    ks = (KStars*) parent;
-
     QFrame *page = new QFrame( this );
     setMainWidget(page);
     setCaption( i18n( "Altitude vs. Time" ) );
     setButtons( KDialog::Close );
     setModal( false );
 
-    topLayout = new QVBoxLayout( page );
+    QVBoxLayout* topLayout = new QVBoxLayout( page );
     topLayout->setMargin( 0 );
     topLayout->setSpacing( spacingHint() );
 
@@ -88,24 +80,24 @@ AltVsTime::AltVsTime( QWidget* parent)  :
 
     topLayout->addWidget( avtUI );
 
-    geo = ks->geo();
+    geo = KStarsData::Instance()->geo();
 
     DayOffset = 0;
     showCurrentDate();
-    if ( getDate().time().hour() > 12 ) DayOffset = 1;
+    if ( getDate().time().hour() > 12 )
+        DayOffset = 1;
 
     avtUI->longBox->show( geo->lng() );
     avtUI->latBox->show( geo->lat() );
 
     computeSunRiseSetTimes();
-
     setLSTLimits();
 
     connect( avtUI->browseButton, SIGNAL( clicked() ), this, SLOT( slotBrowseObject() ) );
     connect( avtUI->cityButton,   SIGNAL( clicked() ), this, SLOT( slotChooseCity() ) );
     connect( avtUI->updateButton, SIGNAL( clicked() ), this, SLOT( slotUpdateDateLoc() ) );
-    connect( avtUI->clearButton, SIGNAL( clicked() ), this, SLOT( slotClear() ) );
-    connect( avtUI->addButton,   SIGNAL( clicked() ), this, SLOT( slotAddSource() ) );
+    connect( avtUI->clearButton , SIGNAL( clicked() ), this, SLOT( slotClear() ) );
+    connect( avtUI->addButton,    SIGNAL( clicked() ), this, SLOT( slotAddSource() ) );
     connect( avtUI->nameBox, SIGNAL( returnPressed() ), this, SLOT( slotAddSource() ) );
     connect( avtUI->raBox,   SIGNAL( returnPressed() ), this, SLOT( slotAddSource() ) );
     connect( avtUI->decBox,  SIGNAL( returnPressed() ), this, SLOT( slotAddSource() ) );
@@ -128,35 +120,34 @@ AltVsTime::~AltVsTime()
 }
 
 void AltVsTime::slotAddSource() {
-    SkyObject *obj = ks->data()->objectNamed( avtUI->nameBox->text() );
+    SkyObject *obj = KStarsData::Instance()->objectNamed( avtUI->nameBox->text() );
 
     if ( obj ) {
         //An object with the current name exists.  If the object is not already
         //in the avt list, add it.
-        bool found(false);
+        bool found = false;
         foreach ( SkyObject *o, pList ) {
-            if ( o->name() == obj->name() ) { found = true; break; }
+            if ( o->name() == obj->name() ) {
+                found = true;
+                break;
+            }
         }
-
-        if ( found )
-            kDebug() << i18n("An object named %1 is already displayed, it will not be duplicated.", obj->name());
-
-        else
+        if( !found )
             processObject( obj );
-
     } else {
         //Object with the current name doesn't exist.  It's possible that the
         //user is trying to add a custom object.  Assume this is the case if
         //the RA and Dec fields are filled in.
 
-        if ( ! avtUI->nameBox->text().isEmpty() &&
-                ! avtUI->raBox->text().isEmpty() &&
-                ! avtUI->decBox->text().isEmpty() ) {
-            bool ok( true );
-            dms newRA( 0.0 ), newDec( 0.0 );
-            newRA = avtUI->raBox->createDms( false, &ok );
-            if ( ok ) newDec = avtUI->decBox->createDms( true, &ok );
-            if ( !ok ) return;
+        if( ! avtUI->nameBox->text().isEmpty() &&
+            ! avtUI->raBox->text().isEmpty()   &&
+            ! avtUI->decBox->text().isEmpty() )
+        {
+            bool okRA, okDec;
+            dms newRA  = avtUI->raBox->createDms( false, &okRA );
+            dms newDec = avtUI->decBox->createDms( true, &okDec );
+            if( !okRA || !okDec )
+                return;
 
             //If the epochName is blank (or any non-double), we assume J2000
             //Otherwise, precess to J2000.
@@ -166,25 +157,20 @@ void AltVsTime::slotAddSource() {
             if ( jd != J2000 ) {
                 SkyPoint ptest( newRA, newDec );
                 ptest.precessFromAnyEpoch( jd, J2000 );
-                newRA.setH( ptest.ra()->Hours() );
-                newDec.setD( ptest.dec()->Degrees() );
+                newRA.setH( ptest.ra().Hours() );
+                newDec.setD( ptest.dec().Degrees() );
             }
 
             //make sure the coords do not already exist from another object
-            bool found(false);
+            bool found = false;
             foreach ( SkyObject *p, pList ) {
                 //within an arcsecond?
-                if ( fabs( newRA.Degrees() - p->ra()->Degrees() ) < 0.0003 && fabs( newDec.Degrees() - p->dec()->Degrees() ) < 0.0003 ) {
+                if ( fabs( newRA.Degrees() - p->ra().Degrees() ) < 0.0003 && fabs( newDec.Degrees() - p->dec().Degrees() ) < 0.0003 ) {
                     found = true;
                     break;
                 }
             }
-            if ( found ) {
-                kDebug() << "This point is already displayed; I will not duplicate it.";
-                ok = false;
-            }
-
-            if ( ok ) {
+            if( !found ) {
                 SkyObject *obj = new SkyObject( 8, newRA, newDec, 1.0, avtUI->nameBox->text() );
                 deleteList.append( obj ); //this object will be deleted when window is destroyed
                 processObject( obj );
@@ -194,12 +180,15 @@ void AltVsTime::slotAddSource() {
         //If the Ra and Dec boxes are filled, but the name field is empty,
         //move input focus to nameBox.  If either coordinate box is empty,
         //move focus there
-        if ( avtUI->nameBox->text().isEmpty() )
+        if( avtUI->nameBox->text().isEmpty() ) {
             avtUI->nameBox->QWidget::setFocus();
-        if ( avtUI->raBox->text().isEmpty() )
+        }
+        if( avtUI->raBox->text().isEmpty() ) {
             avtUI->raBox->QWidget::setFocus();
-        else if ( avtUI->decBox->text().isEmpty() )
-            avtUI->decBox->QWidget::setFocus();
+        } else {
+            if ( avtUI->decBox->text().isEmpty() )
+                avtUI->decBox->QWidget::setFocus();
+        }
     }
 
     avtUI->View->update();
@@ -207,7 +196,7 @@ void AltVsTime::slotAddSource() {
 
 //Use find dialog to choose an object
 void AltVsTime::slotBrowseObject() {
-    QPointer<FindDialog> fd = new FindDialog(ks);
+    QPointer<FindDialog> fd = new FindDialog(this);
     if ( fd->exec() == QDialog::Accepted ) {
         SkyObject *o = fd->selectedObject();
         processObject( o );
@@ -218,15 +207,17 @@ void AltVsTime::slotBrowseObject() {
 }
 
 void AltVsTime::processObject( SkyObject *o, bool forceAdd ) {
-    if ( !o ) return;
+    if( !o )
+        return;
 
     KSNumbers *num = new KSNumbers( getDate().djd() );
     KSNumbers *oldNum = 0;
 
     //If the object is in the solar system, recompute its position for the given epochLabel
+    KStarsData* data = KStarsData::Instance();
     if ( o->isSolarSystem() ) {
-        oldNum = new KSNumbers( ks->data()->ut().djd() );
-        o->updateCoords( num, true, geo->lat(), ks->LST() );
+        oldNum = new KSNumbers( data->ut().djd() );
+        o->updateCoords( num, true, geo->lat(), data->lst() );
     }
 
     //precess coords to target epoch
@@ -235,13 +226,14 @@ void AltVsTime::processObject( SkyObject *o, bool forceAdd ) {
     //If this point is not in list already, add it to list
     bool found(false);
     foreach ( SkyObject *p, pList ) {
-        if ( o->ra()->Degrees() == p->ra()->Degrees() && o->dec()->Degrees() == p->dec()->Degrees() ) {
+        if ( o->ra().Degrees() == p->ra().Degrees() && o->dec().Degrees() == p->dec().Degrees() ) {
             found = true;
             break;
         }
     }
-    if ( found && !forceAdd ) kDebug() << "This point is already displayed; I will not duplicate it.";
-    else {
+    if ( found && !forceAdd ) {
+        kDebug() << "This point is already displayed; I will not duplicate it.";
+    } else {
         pList.append( o );
 
         //make sure existing curves are thin and red
@@ -270,22 +262,22 @@ void AltVsTime::processObject( SkyObject *o, bool forceAdd ) {
 
     //restore original position
     if ( o->isSolarSystem() ) {
-        o->updateCoords( oldNum, true, ks->geo()->lat(), ks->LST() );
+        o->updateCoords( oldNum, true, data->geo()->lat(), data->lst() );
         delete oldNum;
     }
-    o->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
+    o->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
     delete num;
 }
 
 double AltVsTime::findAltitude( SkyPoint *p, double hour ) {
-    hour += 24.0*(double)DayOffset;
+    hour += 24.0 * DayOffset;
 
     //getDate converts the user-entered local time to UT
     KStarsDateTime ut = getDate().addSecs( hour*3600.0 );
 
     dms LST = geo->GSTtoLST( ut.gst() );
     p->EquatorialToHorizontal( &LST, geo->lat() );
-    return p->alt()->Degrees();
+    return p->alt().Degrees();
 }
 
 void AltVsTime::slotHighlight( int row ) {
@@ -314,17 +306,18 @@ void AltVsTime::slotHighlight( int row ) {
 //move input focus to the next logical widget
 void AltVsTime::slotAdvanceFocus() {
     if ( sender()->objectName() == QString( "nameBox" ) ) avtUI->addButton->setFocus();
-    if ( sender()->objectName() == QString( "raBox" ) ) avtUI->decBox->setFocus();
-    if ( sender()->objectName() == QString( "decbox" ) ) avtUI->addButton->setFocus();
+    if ( sender()->objectName() == QString( "raBox" ) )   avtUI->decBox->setFocus();
+    if ( sender()->objectName() == QString( "decbox" ) )  avtUI->addButton->setFocus();
     if ( sender()->objectName() == QString( "longBox" ) ) avtUI->latBox->setFocus();
-    if ( sender()->objectName() == QString( "latBox" ) ) avtUI->updateButton->setFocus();
+    if ( sender()->objectName() == QString( "latBox" ) )  avtUI->updateButton->setFocus();
 }
 
 void AltVsTime::slotClear() {
-    if ( pList.count() ) pList.clear();
+    pList.clear();
     //Need to delete the pointers in deleteList
-    while ( ! deleteList.isEmpty() )
+    while( !deleteList.isEmpty() )
         delete deleteList.takeFirst();
+
     avtUI->PlotList->clear();
     avtUI->nameBox->clear();
     avtUI->raBox->clear();
@@ -345,41 +338,16 @@ void AltVsTime::computeSunRiseSetTimes() {
     //Determine the time of sunset and sunrise for the desired date and location
     //expressed as doubles, the fraction of a full day.
     KStarsDateTime today = getDate();
-
-    SkyObject *oSun = ks->data()->objectNamed( "Sun" );
-    double sunRise = -1.0 * oSun->riseSetTime( today.djd() + 1.0, geo, true ).secsTo(QTime()) / 86400.0;
-    double sunSet = -1.0 * oSun->riseSetTime( today.djd(), geo, false ).secsTo(QTime()) / 86400.0;
-
-    //check to see if Sun is circumpolar
-    //requires temporary repositioning of Sun to target date
-    KSNumbers *num = new KSNumbers( today.djd() );
-    KSNumbers *oldNum = new KSNumbers( ks->data()->ut().djd() );
-    dms LST = geo->GSTtoLST( getDate().gst() );
-    oSun->updateCoords( num, true, geo->lat(), &LST );
-    if ( oSun->checkCircumpolar( geo->lat() ) ) {
-        if ( oSun->alt()->Degrees() > 0.0 ) {
-            //Circumpolar, signal it this way:
-            sunRise = 0.0;
-            sunSet = 1.0;
-        } else {
-            //never rises, signal it this way:
-            sunRise = 0.0;
-            sunSet = -1.0;
-        }
-    }
-
-    //Notify the View about new sun rise/set times:
+    KSAlmanac ksal;
+    ksal.setDate( &today);
+    ksal.setLocation(geo);
+    double sunRise = ksal.getSunRise();
+    double sunSet  = ksal.getSunSet();
     avtUI->View->setSunRiseSetTimes( sunRise, sunSet );
-
-    //Restore Sun coordinates:
-    oSun->updateCoords( oldNum, true, ks->geo()->lat(), ks->LST() );
-    oSun->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
-
-    delete num;
-    delete oldNum;
 }
 
 void AltVsTime::slotUpdateDateLoc() {
+    KStarsData* data = KStarsData::Instance();
     KStarsDateTime today = getDate();
     KSNumbers *num = new KSNumbers( today.djd() );
     KSNumbers *oldNum = 0;
@@ -391,11 +359,11 @@ void AltVsTime::slotUpdateDateLoc() {
     for ( int i = 0; i < avtUI->PlotList->count(); ++i ) {
         QString oName = avtUI->PlotList->item( i )->text().toLower();
 
-        SkyObject *o = ks->data()->objectNamed( oName );
+        SkyObject *o = data->objectNamed( oName );
         if ( o ) {
             //If the object is in the solar system, recompute its position for the given date
             if ( o->isSolarSystem() ) {
-                oldNum = new KSNumbers( ks->data()->ut().djd() );
+                oldNum = new KSNumbers( data->ut().djd() );
                 o->updateCoords( num, true, geo->lat(), &LST );
             }
 
@@ -413,11 +381,11 @@ void AltVsTime::slotUpdateDateLoc() {
 
             //restore original position
             if ( o->isSolarSystem() ) {
-                o->updateCoords( oldNum, true, ks->data()->geo()->lat(), ks->LST() );
+                o->updateCoords( oldNum, true, data->geo()->lat(), data->lst() );
                 delete oldNum;
                 oldNum = 0;
             }
-            o->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
+            o->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         } else {  //assume unfound object is a custom object
             pList.at(i)->updateCoords( num ); //precess to desired epoch
 
@@ -429,8 +397,10 @@ void AltVsTime::slotUpdateDateLoc() {
         }
     }
 
-    if ( getDate().time().hour() > 12 ) DayOffset = 1;
-    else DayOffset = 0;
+    if ( getDate().time().hour() > 12 )
+        DayOffset = 1;
+    else
+        DayOffset = 0;
 
     setLSTLimits();
     slotHighlight( avtUI->PlotList->currentRow() );
@@ -440,7 +410,7 @@ void AltVsTime::slotUpdateDateLoc() {
 }
 
 void AltVsTime::slotChooseCity() {
-    QPointer<LocationDialog> ld = new LocationDialog(ks);
+    QPointer<LocationDialog> ld = new LocationDialog(this);
     if ( ld->exec() == QDialog::Accepted ) {
         GeoLocation *newGeo = ld->selectedCity();
         if ( newGeo ) {
@@ -452,17 +422,14 @@ void AltVsTime::slotChooseCity() {
     delete ld;
 }
 
-int AltVsTime::currentPlotListItem() const {
-    return avtUI->PlotList->currentRow();
-}
-
 void AltVsTime::setLSTLimits() {
     //UT at noon on target date
     KStarsDateTime ut = getDate().addSecs( ((double)DayOffset + 0.5)*86400. );
 
     dms lst = geo->GSTtoLST( ut.gst() );
     double h1 = lst.Hours();
-    if ( h1 > 12.0 ) h1 -= 24.0;
+    if( h1 > 12.0 )
+        h1 -= 24.0;
     double h2 = h1 + 24.0;
     avtUI->View->setSecondaryLimits( h1, h2, -90.0, 90.0 );
 }
@@ -470,7 +437,8 @@ void AltVsTime::setLSTLimits() {
 void AltVsTime::showCurrentDate()
 {
     KStarsDateTime dt = KStarsDateTime::currentDateTime();
-    if ( dt.time() > QTime( 12, 0, 0 ) ) dt = dt.addDays( 1 );
+    if( dt.time() > QTime( 12, 0, 0 ) )
+        dt = dt.addDays( 1 );
     avtUI->DateWidget->setDate( dt.date() );
 }
 
@@ -478,21 +446,18 @@ KStarsDateTime AltVsTime::getDate()
 {
     //convert midnight local time to UT:
     KStarsDateTime dt( avtUI->DateWidget->date(), QTime() );
-    dt = geo->LTtoUT( dt );
-    return dt;
+    return geo->LTtoUT( dt );
 }
 
 double AltVsTime::getEpoch(const QString &eName)
 {
     //If Epoch field not a double, assume J2000
-    bool ok(false);
+    bool ok;
     double epoch = eName.toDouble(&ok);
-
     if ( !ok ) {
         kDebug() << "Invalid Epoch.  Assuming 2000.0.";
         return 2000.0;
     }
-
     return epoch;
 }
 
