@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008 Torsten Rahn <tackat@kde.org>"
+// Copyright 2008 Torsten Rahn <tackat@kde.org>
 // Copyright 2008 Jens-Michael Hoffmann <jensmh@gmx.de>
 //
 
@@ -22,59 +22,87 @@
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QTimer>
-#include <QtCore/QDebug>
 
 // Local dir
 #include "GeoSceneDocument.h"
 #include "GeoSceneHead.h"
 #include "GeoSceneIcon.h"
 #include "GeoSceneParser.h"
+#include "MarbleDebug.h"
 #include "MarbleDirs.h"
 
-using namespace Marble;
-
-namespace {
-    const QString mapDirName = "maps";
-    const int columnRelativePath = 1;
+namespace
+{
+    static const QString mapDirName = "maps";
+    static const int columnRelativePath = 1;
 }
 
-namespace Marble {
+namespace Marble
+{
 
 class MapThemeManagerPrivate
 {
 public:
+    MapThemeManagerPrivate();
+    ~MapThemeManagerPrivate();
     QStandardItemModel* m_mapThemeModel;
     QFileSystemWatcher* m_fileSystemWatcher;
+    bool m_isInitialized;
 };
 
+MapThemeManagerPrivate::MapThemeManagerPrivate()
+    : m_mapThemeModel( new QStandardItemModel( 0, 3 ) ),
+      m_fileSystemWatcher( new QFileSystemWatcher ),
+      m_isInitialized( false )
+{
 }
 
-MapThemeManager::MapThemeManager(QObject *parent)
-    : QObject(parent),
-    d(new MapThemeManagerPrivate)
+MapThemeManagerPrivate::~MapThemeManagerPrivate()
 {
-    d->m_mapThemeModel = new QStandardItemModel( 0, 3 );
-    initFileSystemWatcher();
+    delete m_mapThemeModel;
+    delete m_fileSystemWatcher;
+}
 
-    // Delayed model initialization
-    QTimer::singleShot( 0, this, SLOT( updateMapThemeModel() ) );
+
+MapThemeManager::MapThemeManager( QObject *parent )
+    : QObject( parent ),
+      d( new MapThemeManagerPrivate )
+{
+    initFileSystemWatcher();
 }
 
 MapThemeManager::~MapThemeManager()
 {
-    delete d->m_mapThemeModel;
-    delete d->m_fileSystemWatcher;
     delete d;
 }
 
+QList<GeoSceneDocument const*> MapThemeManager::mapThemes() const
+{
+    QList<GeoSceneDocument const*> result;
+    const QStringList mapThemes = findMapThemes();
+    QStringList::const_iterator pos = mapThemes.constBegin();
+    QStringList::const_iterator const end = mapThemes.constEnd();
+    for (; pos != end; ++pos ) {
+        result.append( loadMapTheme( *pos ));
+    }
+    return result;
+}
+
+void MapThemeManager::initialize()
+{
+    // Delayed model initialization
+    updateMapThemeModel();
+    d->m_isInitialized = true;
+}
+
 void MapThemeManager::initFileSystemWatcher()
 {
     const QStringList paths = pathsToWatch();
 /*
     foreach(const QString& path, paths)
-        qDebug() << "path to watch: " << path;
+        mDebug() << "path to watch: " << path;
 */
-    d->m_fileSystemWatcher = new QFileSystemWatcher( paths, this );
+    d->m_fileSystemWatcher->addPaths( paths );
     connect( d->m_fileSystemWatcher, SIGNAL( directoryChanged( const QString& )),
              this, SLOT( directoryChanged( const QString& )));
     connect( d->m_fileSystemWatcher, SIGNAL( fileChanged( const QString& )),
@@ -86,7 +114,7 @@ GeoSceneDocument* MapThemeManager::loadMapTheme( const QString& mapThemeStringID
     if ( mapThemeStringID.isEmpty() )
         return 0;
 
-    qDebug() << "loadMapTheme" << mapThemeStringID;
+    mDebug() << "loadMapTheme" << mapThemeStringID;
     const QString mapThemePath = mapDirName + '/' + mapThemeStringID;
     return loadMapThemeFile( mapThemePath );
 }
@@ -95,25 +123,24 @@ GeoSceneDocument* MapThemeManager::loadMapThemeFile( const QString& mapThemePath
 {
     // Check whether file exists
     QFile file( MarbleDirs::path( mapThemePath ) );
-    if (!file.exists()) {
-        qDebug() << "File does not exist:" << MarbleDirs::path( mapThemePath );
+    if ( !file.exists() ) {
+        mDebug() << "File does not exist:" << MarbleDirs::path( mapThemePath );
         return 0;
     }
 
     // Open file in right mode
-    file.open(QIODevice::ReadOnly);
+    file.open( QIODevice::ReadOnly );
 
-    GeoSceneParser parser(GeoScene_DGML);
+    GeoSceneParser parser( GeoScene_DGML );
 
-    if (!parser.read(&file)) {
+    if ( !parser.read( &file )) {
         qDebug("Could not parse file!");
         return 0;
     }
 
     // Get result document
-    GeoSceneDocument* document = static_cast<GeoSceneDocument*>(parser.releaseDocument());
-    Q_ASSERT(document);
-
+    GeoSceneDocument* document = static_cast<GeoSceneDocument*>( parser.releaseDocument() );
+    Q_ASSERT( document );
     return document;
 }
 
@@ -123,6 +150,10 @@ QStringList MapThemeManager::pathsToWatch()
     const QString localMapPathName = MarbleDirs::localPath() + '/' + mapDirName;
     const QString systemMapPathName = MarbleDirs::systemPath() + '/' + mapDirName;
 
+    if( !QDir().exists( localMapPathName ) ) {
+        QDir().mkpath( localMapPathName );
+    }
+
     result << localMapPathName;
     result << systemMapPathName;
     addMapThemePaths( localMapPathName, result );
@@ -143,7 +174,6 @@ QStringList MapThemeManager::findMapThemes( const QString& basePath )
     QStringList mapDirs;
 
     for ( int planet = 0; planet < mapPaths.size(); ++planet ) {
-
         QDir themeDir = QDir( mapPathName + '/' + mapPaths.at( planet ) );
         QStringList themeMapPaths = themeDir.entryList( 
                                      QStringList( "*" ),
@@ -156,14 +186,13 @@ QStringList MapThemeManager::findMapThemes( const QString& basePath )
         }
     }
 
-
     QStringList mapFiles;
     QStringListIterator it( mapDirs );
     while ( it.hasNext() ) {
         QString themeDir = it.next() + '/';
-        QString themeDirName = QDir( themeDir ).path().section( '/', -2, -1);
-        QStringList tmp = ( QDir( themeDir ) ).entryList( QStringList( "*.dgml" ),
-                                              QDir::Files | QDir::NoSymLinks );
+        QString themeDirName = QDir( themeDir ).path().section( '/', -2, -1 );
+        QStringList tmp = QDir( themeDir ).entryList( QStringList( "*.dgml" ),
+                                                      QDir::Files | QDir::NoSymLinks );
         if ( !tmp.isEmpty() ) {
             QStringListIterator k( tmp );
             while ( k.hasNext() ) {
@@ -186,8 +215,8 @@ QStringList MapThemeManager::findMapThemes()
     // remove duplicate entries
     allMapFiles.sort();
     for ( int i = 1; i < allMapFiles.size(); ++i ) {
-        if ( allMapFiles.at(i) == allMapFiles.at( i - 1 ) ) {
-            allMapFiles.removeAt(i);
+        if ( allMapFiles.at(i) == allMapFiles.at( i-1 ) ) {
+            allMapFiles.removeAt( i );
             --i;
         }
     }
@@ -197,6 +226,9 @@ QStringList MapThemeManager::findMapThemes()
 
 QStandardItemModel* MapThemeManager::mapThemeModel()
 {
+    if ( !d->m_isInitialized ) {
+        initialize();
+    }
     return d->m_mapThemeModel;
 }
 
@@ -227,14 +259,14 @@ QList<QStandardItem *> MapThemeManager::createMapThemeRow( QString const& mapThe
         //       For now maxIconSize already equals what's expected by the listview.
         QSize maxIconSize( 136, 136 );
         if ( themeIconPixmap.size() != maxIconSize ) {
-            qDebug() << "Smooth scaling theme icon";
-            themeIconPixmap = themeIconPixmap.scaled( maxIconSize, 
-                                                    Qt::KeepAspectRatio,
-                                                    Qt::SmoothTransformation );
+            mDebug() << "Smooth scaling theme icon";
+            themeIconPixmap = themeIconPixmap.scaled( maxIconSize,
+                                                      Qt::KeepAspectRatio,
+                                                      Qt::SmoothTransformation );
         }
     }
 
-    QIcon mapThemeIcon =  QIcon(themeIconPixmap);
+    QIcon mapThemeIcon =  QIcon( themeIconPixmap );
 
     QString name = mapTheme->head()->name();
     QString description = mapTheme->head()->description();
@@ -242,11 +274,11 @@ QList<QStandardItem *> MapThemeManager::createMapThemeRow( QString const& mapThe
     QStandardItem *item = new QStandardItem( name );
     item->setData( tr( name.toUtf8() ), Qt::DisplayRole );
     item->setData( mapThemeIcon, Qt::DecorationRole );
-    item->setData( QString( "<span style=\" max-width: 150 px;\"> " 
-                   + tr( description.toUtf8() ) + " </span>"), Qt::ToolTipRole);
+    item->setData( QString( "<span style=\" max-width: 150 px;\"> "
+                            + tr( description.toUtf8() ) + " </span>" ), Qt::ToolTipRole );
 
     itemList << item;
-    itemList << new QStandardItem( mapTheme->head()->target() + '/' 
+    itemList << new QStandardItem( mapTheme->head()->target() + '/'
                                    + mapTheme->head()->theme() + '/'
                                    + mapTheme->head()->theme() + ".dgml" );
     itemList << new QStandardItem( tr( description.toUtf8() ) );
@@ -258,6 +290,7 @@ QList<QStandardItem *> MapThemeManager::createMapThemeRow( QString const& mapThe
 
 void MapThemeManager::updateMapThemeModel()
 {
+    mDebug() << "updateMapThemeModel";
     d->m_mapThemeModel->clear();
 
     d->m_mapThemeModel->setHeaderData(0, Qt::Horizontal, tr("Name"));
@@ -265,31 +298,33 @@ void MapThemeManager::updateMapThemeModel()
     d->m_mapThemeModel->setHeaderData(2, Qt::Horizontal, tr("Description"));
 
     QStringList stringlist = findMapThemes();
-    QStringListIterator  it(stringlist);
+    QStringListIterator it( stringlist );
 
     while ( it.hasNext() ) {
         QString mapThemeID = it.next();
 
     	QList<QStandardItem *> itemList = createMapThemeRow( mapThemeID );
         if ( !itemList.empty() ) {
-            d->m_mapThemeModel->appendRow(itemList);
+            d->m_mapThemeModel->appendRow( itemList );
         }
     }
 }
 
 void MapThemeManager::directoryChanged( const QString& path )
 {
-    qDebug() << "directoryChanged:" << path;
+    mDebug() << "directoryChanged:" << path;
 
     QStringList paths = pathsToWatch();
     d->m_fileSystemWatcher->addPaths( paths );
 
+    mDebug() << "Emitting themesChanged()";
+    emit themesChanged();
     updateMapThemeModel();
 }
 
 void MapThemeManager::fileChanged( const QString& path )
 {
-    qDebug() << "fileChanged:" << path;
+    mDebug() << "fileChanged:" << path;
 
     // 1. if the file does not (anymore) exist, it got deleted and we
     //    have to delete the corresponding item from the model
@@ -297,12 +332,12 @@ void MapThemeManager::fileChanged( const QString& path )
     //    the item with a new one.
 
     QString mapThemeId = path.section( '/', -3 );
-    qDebug() << "mapThemeId:" << mapThemeId;
+    mDebug() << "mapThemeId:" << mapThemeId;
     QList<QStandardItem *> matchingItems = d->m_mapThemeModel->findItems( mapThemeId,
-                                                                       Qt::MatchFixedString
-				                                       | Qt::MatchCaseSensitive,
-                                                                       columnRelativePath );
-    qDebug() << "matchingItems:" << matchingItems.size();
+                                                                          Qt::MatchFixedString
+                                                                          | Qt::MatchCaseSensitive,
+                                                                          columnRelativePath );
+    mDebug() << "matchingItems:" << matchingItems.size();
     Q_ASSERT( matchingItems.size() <= 1 );
     int insertAtRow = 0;
 
@@ -322,6 +357,8 @@ void MapThemeManager::fileChanged( const QString& path )
             d->m_mapThemeModel->insertRow( insertAtRow, newMapThemeRow );
         }
     }
+    
+    emit themesChanged();
 }
 
 //
@@ -362,4 +399,6 @@ void MapThemeManager::addMapThemePaths( const QString& mapPathName, QStringList&
     }
 }
 
+}
+
 #include "MapThemeManager.moc"
