@@ -5,27 +5,21 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2004-2007 Torsten Rahn  <tackat@kde.org>"
-// Copyright 2007      Inge Wallin   <ingwa@kde.org>"
-// Copyright 2007      Thomas Zander <zander@kde.org>"
+// Copyright 2004-2007 Torsten Rahn  <tackat@kde.org>
+// Copyright 2007      Inge Wallin   <ingwa@kde.org>
+// Copyright 2007      Thomas Zander <zander@kde.org>
 //
 
-//
-// The TextureColorizer maps the Elevationvalues to Legend Colors.
-//
-
-
-#ifndef MARBLECONTROLBOX_H
-#define MARBLECONTROLBOX_H
+#ifndef MARBLE_MARBLECONTROLBOX_H
+#define MARBLE_MARBLECONTROLBOX_H
 
 
 #include "marble_export.h"
+#include "PositionProviderPlugin.h"
 
-#include <QtCore/QString>
 #include <QtGui/QWidget>
 
 #include "global.h"
-#include "GeoDataCoordinates.h"       // In geodata/data/
 
 
 /** @file
@@ -35,16 +29,15 @@
  * @author Inge Wallin  <inge@lysator.liu.se>
  */
 
-class QByteArray;
 class QModelIndex;
-class QAbstractItemModel;
 class QResizeEvent;
 class QStandardItemModel;
+class QString;
 
 namespace Marble
 {
 
-class GeoDataDocument;
+class GeoDataCoordinates;
 class MarbleWidget;
 class MarbleControlBoxPrivate;
 class MarblePlacemarkModel;
@@ -72,7 +65,7 @@ class MarblePlacemarkModel;
  * The <b>Map View</b> page gives the user a choice of different
  * datasets to display, which can also be thought of as different
  * visual themes. The default datasets are a standard Atlas view, a
- * Night view, and a Sattelite view.
+ * Night view, and a Satellite view.
  *
  * @see MarbleWidget
  * @see MarbleNavigator
@@ -87,7 +80,7 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
      * @brief Construct a new MarbleControlBox
      * @param parent the parent widget
      */
-    explicit MarbleControlBox(QWidget *parent = 0);
+    explicit MarbleControlBox( QWidget *parent = 0 );
     ~MarbleControlBox();
  
     /**
@@ -111,6 +104,11 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
   
     void updateCelestialModel();
 
+    /**
+      * Toggle offline mode of download manager and runners.
+      */
+    void setWorkOffline(bool offline);
+
  Q_SIGNALS:
     /**
      * @brief Signal emitted when the Home button has been pressed.
@@ -165,8 +163,7 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
     void projectionSelected( Projection );
     
     void gpsInputDisabled( bool );
-    void gpsPositionChanged( qreal lat, qreal lon);
-    void updateGps();
+    void gpsPositionChanged( qreal lat, qreal lon );
    
  public Q_SLOTS:
 
@@ -196,8 +193,8 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
      * value of the slider, but nothing more.  In particular it
      * doesn't emit the zoomChanged signal.
      */
-    void changeZoom(int zoom);
-    void receiveGpsCoordinates( GeoDataCoordinates in, qreal speed  );
+    void changeZoom( int zoom );
+    void receiveGpsCoordinates( const GeoDataCoordinates& in, qreal speed );
     void enableFileViewActions();
     
     /**
@@ -234,7 +231,7 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
  private Q_SLOTS:
 
     /// called whenever the user types something new in the search box
-    void searchLineChanged(const QString &search);
+    void searchLineChanged( const QString &search );
     
     /// called the Return or Enter key is pressed in the search box.
     void searchReturnPressed();
@@ -248,6 +245,10 @@ class MARBLE_EXPORT MarbleControlBox : public QWidget
     void adjustForAnimation();
     void adjustForStill();
 
+    void changePositionProvider( const QString &provider );
+    void adjustPositionTrackingStatus( PositionProviderStatus status );
+    void centerOnCurrentLocation();
+
  private:
     void setWidgetTabShown( QWidget * widget, int insertIndex, 
                             bool show, QString &text );
@@ -260,13 +261,13 @@ protected:
      * Navigation tab will be hidden, leaving only the Zoom Up and
      * Zoom Down buttons.
      */
-    void resizeEvent ( QResizeEvent * );
+    void resizeEvent( QResizeEvent * );
 
  private:
     Q_DISABLE_COPY( MarbleControlBox )
-    MarbleControlBoxPrivate  * const d;
+    MarbleControlBoxPrivate * const d;
 };
 
 }
 
-#endif // MARBLECONTROLBOX_H
+#endif
