@@ -9,9 +9,8 @@
 // Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
-
-#ifndef MARBLE_LOCALE_H
-#define MARBLE_LOCALE_H
+#ifndef MARBLE_MARBLELOCALE_H
+#define MARBLE_MARBLELOCALE_H
 
 #include "marble_export.h"
 #include "global.h"
@@ -34,14 +33,13 @@ class MARBLE_EXPORT MarbleLocale
     MarbleLocale();
     ~MarbleLocale();
 
-    void setDistanceUnit( Marble::DistanceUnit distanceUnit );
-    Marble::DistanceUnit distanceUnit() const;
+    void setDistanceUnit( DistanceUnit distanceUnit );
+    DistanceUnit distanceUnit() const;
 
-    void setMeasureSystem( Marble::MeasureSystem measureSystem );
-    Marble::MeasureSystem measureSystem() const;
+    void setMeasureSystem( MeasureSystem measureSystem );
+    MeasureSystem measureSystem() const;
 
     static QString languageCode();
-    static QString simpleLanguageCode();
 
  private:
     Q_DISABLE_COPY( MarbleLocale )
@@ -50,4 +48,4 @@ class MARBLE_EXPORT MarbleLocale
 
 }
 
-#endif // MARBLE_LOCALE_H
+#endif
