@@ -13,9 +13,8 @@
 // The MarbleWidgetInputHandler handles mouse and keyboard input.
 //
 
-
-#ifndef MARBLEWIDGETINPUTHANDLER_H
-#define MARBLEWIDGETINPUTHANDLER_H
+#ifndef MARBLE_MARBLEWIDGETINPUTHANDLER_H
+#define MARBLE_MARBLEWIDGETINPUTHANDLER_H
 
 #include <QtCore/QObject>
 #include <QtCore/QString>
@@ -92,7 +91,7 @@ class MARBLE_EXPORT MarbleWidgetDefaultInputHandler  : public MarbleWidgetInputH
     MarbleWidgetDefaultInputHandler();
     ~MarbleWidgetDefaultInputHandler();
 
-    static bool keyEvent( MarbleMap * map, QEvent* e );
+    static bool keyEvent( MarbleWidget * widget, QEvent* e );
     
     virtual void init( MarbleWidget* );
 
@@ -106,7 +105,12 @@ class MARBLE_EXPORT MarbleWidgetDefaultInputHandler  : public MarbleWidgetInputH
 
     void openItemToolTip();
 
-    
+    void lmbTimeout();
+
+    void addMeasurePoint();
+
+    void setNumberOfMeasurePoints( int number );
+
  private:
     Q_DISABLE_COPY( MarbleWidgetDefaultInputHandler )
     class Private;
@@ -115,4 +119,4 @@ class MARBLE_EXPORT MarbleWidgetDefaultInputHandler  : public MarbleWidgetInputH
 
 }
 
-#endif // MARBLEWIDGETINPUTHANDLER
+#endif
