@@ -112,9 +112,9 @@ bool AbstractProjection::screenCoordinates( const GeoDataCoordinates &geopoint,
     return screenCoordinates( geopoint, viewport, x, y, globeHidesPoint );
 }
 
-bool AbstractProjection::screenCoordinates( const Marble::GeoDataCoordinates &coordinates,
+bool AbstractProjection::screenCoordinates( const GeoDataCoordinates &coordinates,
                                     const ViewportParams *viewport,
-                                    qreal *x, qreal &y, int &pointRepeatNum,                                    bool &globeHidesPoint )
+                                    qreal *x, qreal &y, int &pointRepeatNum, bool &globeHidesPoint )
 {
     return screenCoordinates( coordinates, viewport, x, y, pointRepeatNum, 
            QSizeF( 0.0, 0.0 ), globeHidesPoint );
@@ -134,7 +134,7 @@ bool AbstractProjection::screenCoordinates( const GeoDataLineString &lineString,
     QVector<GeoDataLineString*> lineStrings;
 
     if (
-         ( !traversablePoles() && lineString.latLonAltBox().containsPole( Marble::AnyPole ) ) ||
+         ( !traversablePoles() && lineString.latLonAltBox().containsPole( AnyPole ) ) ||
          ( lineString.latLonAltBox().crossesDateLine() )
        ) {
         // We correct for Poles and DateLines:
@@ -356,7 +356,8 @@ bool AbstractProjection::lineStringToPolygon( const GeoDataLineString &lineStrin
 
 
 void AbstractProjectionPrivate::repeatPolygons( const ViewportParams *viewport,
-                                                QVector<QPolygonF *> &polygons ) {
+                                                QVector<QPolygonF *> &polygons ) const
+{
     if ( !q->repeatX() ) {
         // The projection doesn't allow repeats in direction of the x-axis
         return;
@@ -428,7 +429,8 @@ void AbstractProjectionPrivate::repeatPolygons( const ViewportParams *viewport,
 
 void AbstractProjectionPrivate::translatePolygons( const QVector<QPolygonF *> &polygons,
                                                    QVector<QPolygonF *> &translatedPolygons,
-                                                   qreal xOffset ) {
+                                                   qreal xOffset ) const
+{
 //    mDebug() << "Translation: " << xOffset;
 
     QVector<QPolygonF *>::const_iterator itPolygon = polygons.constBegin();
@@ -448,7 +450,8 @@ void AbstractProjectionPrivate::manageHorizonCrossing( bool globeHidesPoint,
                                                 bool& horizonPair,
                                                 GeoDataCoordinates& horizonDisappearCoords,
                                                 bool& horizonOrphan,
-                                                GeoDataCoordinates& horizonOrphanCoords ) {
+                                                GeoDataCoordinates& horizonOrphanCoords ) const
+{
     if ( !horizonPair ) {
         if ( globeHidesPoint ) {
             horizonDisappearCoords = horizonCoords;
@@ -464,7 +467,8 @@ void AbstractProjectionPrivate::manageHorizonCrossing( bool globeHidesPoint,
 void AbstractProjection::horizonToPolygon( const ViewportParams *viewport,
                                            const GeoDataCoordinates & disappearCoords,
                                            const GeoDataCoordinates & reappearCoords,
-                                           QPolygonF * polygon ) {
+                                           QPolygonF * polygon )
+{
     qreal x, y;
 
     const qreal imageHalfWidth  = viewport->width() / 2;
@@ -687,7 +691,7 @@ QPolygonF AbstractProjectionPrivate::processTessellation(  const GeoDataCoordina
                                                     const GeoDataCoordinates &currentCoords,
                                                     int tessellatedNodes,
                                                     const ViewportParams *viewport,
-                                                    TessellationFlags f )
+                                                    TessellationFlags f ) const
 {
     QPolygonF   path;
 
@@ -817,7 +821,7 @@ GeoDataCoordinates AbstractProjectionPrivate::findHorizon( const GeoDataCoordina
                                                     const GeoDataCoordinates & currentCoords,
                                                     const ViewportParams *viewport,
                                                     TessellationFlags f,
-                                                    int recursionCounter )
+                                                    int recursionCounter ) const
 {
     bool currentHide = globeHidesPoint( currentCoords, viewport ) ;
 
@@ -883,7 +887,7 @@ GeoDataCoordinates AbstractProjectionPrivate::findHorizon( const GeoDataCoordina
 
 
 bool AbstractProjectionPrivate::globeHidesPoint( const GeoDataCoordinates &coordinates,
-                                          const ViewportParams *viewport )
+                                          const ViewportParams *viewport ) const
 {
     qreal       absoluteAltitude = coordinates.altitude() + EARTH_RADIUS;
     Quaternion  qpos             = coordinates.quaternion();
