@@ -5,12 +5,11 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2007      Torsten Rahn     <tackat@kde.org>"
+// Copyright 2007      Torsten Rahn     <tackat@kde.org>
 //
 
-
-#ifndef SPHERICALSCANLINETEXTUREMAPPER_H
-#define SPHERICALSCANLINETEXTUREMAPPER_H
+#ifndef MARBLE_SPHERICALSCANLINETEXTUREMAPPER_H
+#define MARBLE_SPHERICALSCANLINETEXTUREMAPPER_H
 
 
 #include <QtGui/QColor>
@@ -21,7 +20,7 @@
 namespace Marble
 {
 
-class TileLoader;
+class StackedTileLoader;
 
 
 /*
@@ -36,23 +35,15 @@ class TileLoader;
 class SphericalScanlineTextureMapper : public AbstractScanlineTextureMapper
 {
  public:
-    explicit SphericalScanlineTextureMapper( TileLoader *tileLoader, QObject * parent =0 );
-    virtual ~SphericalScanlineTextureMapper();
+    SphericalScanlineTextureMapper( GeoSceneTexture *textureLayer, StackedTileLoader *tileLoader,
+                                    QObject *parent = 0 );
 
-    void resizeMap(int width, int height);
     void mapTexture( ViewParams *viewParams );
 
  protected:
-    void pixelValueApprox(const qreal& lon, const qreal& lat,
-                          QRgb *scanLine, bool smooth );
-
-    bool         m_interpolate;
-    int          m_nBest;
-
-    int     m_n;
-    qreal  m_nInverse;
+    inline bool needsFilter( const QRgb& rgb, int& oldR, int& oldB, int &oldG  );
 };
 
 }
 
-#endif // SPHERICALSCANLINETEXTUREMAPPER_H
+#endif
