@@ -16,6 +16,7 @@
 
 // Qt
 #include <QtCore/QDir>
+#include <QtCore/QPointer>
 #include <QtCore/QStringList>
 #include <QtCore/QTimer>
 #include <QtGui/QClipboard>
@@ -23,6 +24,7 @@
 #include <QtGui/QFontMetrics>
 #include <QtGui/QPrinter>
 #include <QtGui/QPrintDialog>
+#include <QtGui/QPrintPreviewDialog>
 #include <QtGui/QProgressBar>
 #include <QtGui/QPainter>
 #include <QtGui/QStandardItemModel>
@@ -36,6 +38,7 @@
 #include <kconfigdialog.h>
 #include <kdeversion.h>
 #include <kfiledialog.h>
+#include <kicon.h>
 #include <kmenu.h>
 #include <kmessagebox.h>
 #include <kparts/genericfactory.h>
@@ -44,29 +47,33 @@
 #include <kstatusbar.h>
 #include <ktoggleaction.h>
 #include <ktogglefullscreenaction.h>
-#include <knewstuff2/ui/knewstuffaction.h>
-#include <knewstuff2/engine.h>
+#include <knewstuff3/knewstuffaction.h>
+#include <knewstuff3/downloaddialog.h>
 #include <KStandardDirs>
 #include <kdeprintdialog.h>
 
-// Marble library
-#include "GeoDataCoordinates.h"
-#include "lib/SunControlWidget.h"
-
-// Local dir
-#include "MarbleCacheSettingsWidget.h"
-#include "MarblePluginSettingsWidget.h"
-
-#include <MarbleDirs.h>
-#include <ControlView.h>
-#include "MarbleLocale.h"
-#include "settings.h"
-
+// Marble library classes
 #include "AbstractFloatItem.h"
 #include "AbstractDataPlugin.h"
+#include "DownloadRegionDialog.h"
+#include "GeoDataCoordinates.h"
+#include "GeoDataLatLonAltBox.h"
 #include "HttpDownloadManager.h"
+#include "MarbleCacheSettingsWidget.h"
+#include "MarbleDirs.h"
+#include "MarbleLocale.h"
 #include "MarbleMap.h"
 #include "MarbleModel.h"
+#include "MarblePluginSettingsWidget.h"
+#include "SunControlWidget.h"
+#include "SunLocator.h"
+#include "TileCoordsPyramid.h"
+#include "ViewParams.h"
+#include "ViewportParams.h"
+
+// Marble non-library classes
+#include "ControlView.h"
+#include "settings.h"
 
 using namespace Marble;
 
@@ -88,8 +95,8 @@ K_EXPORT_COMPONENT_FACTORY( libmarble_part, MarblePartFactory )
 
 MarblePart::MarblePart( QWidget *parentWidget, QObject *parent, const QStringList &arguments )
   : KParts::ReadOnlyPart( parent ),
-    m_controlView( new ControlView( parentWidget ) ),
     m_sunControlDialog( 0 ),
+    m_downloadRegionDialog( 0 ),
     m_pluginModel( 0 ),
     m_configDialog( 0 ),
     m_positionLabel( 0 ),
@@ -99,6 +106,20 @@ MarblePart::MarblePart( QWidget *parentWidget, QObject *parent, const QStringLis
     if ( arguments.count() != 0 && !arguments.first().isEmpty() )
         MarbleDirs::setMarbleDataPath( arguments.first() );
 
+    // Setting measure system to provide nice standards for all unit questions.
+    // This has to happen before any initialization so plugins (for example) can
+    // use it during initialization.
+    MarbleLocale *marbleLocale = MarbleGlobal::getInstance()->locale();
+    KLocale *kLocale = KGlobal::locale();
+    if ( kLocale->measureSystem() == KLocale::Metric ) {
+        marbleLocale->setMeasureSystem( Metric );
+    }
+    else {
+        marbleLocale->setMeasureSystem( Imperial );
+    }
+    
+    m_controlView = new ControlView( parentWidget );
+
     setComponentData( MarblePartFactory::componentData() );
 
     setWidget( m_controlView );
@@ -154,12 +175,11 @@ bool MarblePart::openUrl( const KUrl &url )
 
 bool MarblePart::openFile()
 {
-    QString fileName;
-    fileName = KFileDialog::getOpenFileName( KUrl(),
+    QStringList fileNames = KFileDialog::getOpenFileNames( KUrl(),
                                     i18n("*.gpx *.kml|All Supported Files\n*.gpx|GPS Data\n*.kml|Google Earth KML"),
                                             widget(), i18n("Open File")
                                            );
-    if ( ! fileName.isNull() ) {
+    foreach( const QString &fileName, fileNames ) {
         QString extension = fileName.section( '.', -1 );
 
         if ( extension.compare( "gpx", Qt::CaseInsensitive ) == 0 ) {
@@ -202,29 +222,61 @@ void MarblePart::exportMapScreenShot()
 
 void MarblePart::printMapScreenShot()
 {
-    QPixmap       mapPixmap = m_controlView->mapScreenShot();
-    QSize         printSize = mapPixmap.size();
-    QPrinter      printer;
-
+#ifndef QT_NO_PRINTER
+    QPrinter printer( QPrinter::HighResolution );
     QPrintDialog *printDialog = KdePrint::createPrintDialog(&printer, widget());
 
-    if ( printDialog->exec() ) {
-
-        QRect  mapPageRect = printer.pageRect();
-
-        printSize.scale( ( printer.pageRect() ).size(), Qt::KeepAspectRatio );
-
-        QPoint  printTopLeft( mapPageRect.x() + mapPageRect.width() / 2
-                              - printSize.width() / 2,
-                              mapPageRect.y() + mapPageRect.height() / 2
-                              - printSize.height() / 2 );
-
-        QRect     mapPrintRect( printTopLeft, printSize );
-        QPainter  painter( &printer );
-
-        painter.drawPixmap( mapPrintRect, mapPixmap, mapPixmap.rect() );
+    if (printDialog->exec()) {
+        QPixmap mapPixmap = m_controlView->mapScreenShot();
+        printPixmap( &printer, mapPixmap );
     }
+    
     delete printDialog;
+#endif
+}
+
+void MarblePart::printPixmap( QPrinter * printer, const QPixmap& pixmap  )
+{
+#ifndef QT_NO_PRINTER
+    QSize printSize = pixmap.size();
+
+    QRect mapPageRect = printer->pageRect();
+
+    printSize.scale( printer->pageRect().size(), Qt::KeepAspectRatio );
+
+    QPoint printTopLeft( ( mapPageRect.width() - printSize.width() ) / 2 ,
+                         ( mapPageRect.height() - printSize.height() ) / 2 );
+
+    QRect mapPrintRect( printTopLeft, printSize );
+
+    QPainter painter;
+    if (!painter.begin(printer))
+        return;
+    painter.drawPixmap( mapPrintRect, pixmap, pixmap.rect() );
+    painter.end();
+#endif
+}
+
+// QPointer is used because of issues described in http://www.kdedevelopers.org/node/3919
+void MarblePart::printPreview()
+{
+#ifndef QT_NO_PRINTER
+    QPrinter printer( QPrinter::HighResolution );
+
+    QPointer<QPrintPreviewDialog> preview = new QPrintPreviewDialog( &printer, widget() );
+    preview->setWindowFlags( Qt::Window );
+    connect( preview, SIGNAL( paintRequested( QPrinter * ) ), SLOT( paintPrintPreview( QPrinter * ) ) );
+    preview->exec();
+    delete preview;
+#endif
+}
+
+void MarblePart::paintPrintPreview( QPrinter * printer )
+{
+#ifndef QT_NO_PRINTER
+    QPixmap mapPixmap = m_controlView->mapScreenShot();
+    printPixmap( printer, mapPixmap );
+#endif
 }
 
 void MarblePart::setShowClouds( bool isChecked )
@@ -307,9 +359,9 @@ void MarblePart::showSun( bool active )
 
 void MarblePart::workOffline( bool offline )
 {
-    HttpDownloadManager * const downloadManager =
-        m_controlView->marbleWidget()->map()->model()->downloadManager();
-    downloadManager->setDownloadEnabled( !offline );
+    m_controlView->marbleControl()->setWorkOffline( offline );
+    m_newStuffAction->setEnabled( !offline );
+    m_downloadRegionAction->setEnabled( !offline );
 }
 
 void MarblePart::copyMap()
@@ -338,9 +390,9 @@ void MarblePart::setShowCurrentLocation( bool show )
 
 void MarblePart::readSettings()
 {
-    qDebug() << "Start: MarblePart::readSettings()";
+    kDebug() << "Start: MarblePart::readSettings()";
     // Last location on quit
-    if ( MarbleSettings::onStartup() == Marble::LastLocationVisited ) {
+    if ( MarbleSettings::onStartup() == LastLocationVisited ) {
         m_controlView->marbleWidget()->centerOn(
             MarbleSettings::quitLongitude(),
             MarbleSettings::quitLatitude() );
@@ -351,12 +403,16 @@ void MarblePart::readSettings()
     m_controlView->marbleWidget()->setHome( MarbleSettings::homeLongitude(),
                                             MarbleSettings::homeLatitude(),
                                             MarbleSettings::homeZoom() );
-    if ( MarbleSettings::onStartup() == Marble::ShowHomeLocation ) {
+    if ( MarbleSettings::onStartup() == ShowHomeLocation ) {
         m_controlView->marbleWidget()->goHome();
     }
 
     // Map theme and projection
-    m_controlView->marbleWidget()->setMapThemeId( MarbleSettings::mapTheme() );
+    QString mapTheme = MarbleSettings::mapTheme();
+    if ( mapTheme.isEmpty() ) {
+        mapTheme = m_controlView->defaultMapThemeId();
+    }
+    m_controlView->marbleWidget()->setMapThemeId( mapTheme );
     m_controlView->marbleWidget()->setProjection( (Projection) MarbleSettings::projection() );
 
     m_controlView->marbleWidget()->setShowClouds( MarbleSettings::showClouds() );
@@ -379,7 +435,7 @@ void MarblePart::readSettings()
     m_controlView->sunLocator()->setCentered( MarbleSettings::centerOnSun() );
 
     // View
-    m_initialGraphicsSystem = (Marble::GraphicsSystem) MarbleSettings::graphicsSystem();
+    m_initialGraphicsSystem = (GraphicsSystem) MarbleSettings::graphicsSystem();
     m_previousGraphicsSystem = m_initialGraphicsSystem;
 
     // Plugins
@@ -406,7 +462,8 @@ void MarblePart::readSettings()
 
     QList<RenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         if ( pluginEnabled.contains( (*i)->nameId() ) ) {
             (*i)->setEnabled( pluginEnabled[ (*i)->nameId() ] );
             // I think this isn't needed, as it is part of setEnabled()
@@ -419,8 +476,12 @@ void MarblePart::readSettings()
 
     readStatusBarSettings();
 
-    slotUpdateSettings();
-    qDebug() << "Stop: MarblePart::readSettings()";
+    updateSettings();
+    readPluginSettings();
+    disconnect( m_controlView->marbleWidget(), SIGNAL( pluginSettingsChanged() ),
+                this,                          SLOT( writePluginSettings() ) );
+    connect( m_controlView->marbleWidget(), SIGNAL( pluginSettingsChanged() ),
+             this,                          SLOT( writePluginSettings() ) );
 }
 
 void MarblePart::readStatusBarSettings()
@@ -482,12 +543,12 @@ void MarblePart::writeSettings()
 
     MarbleSettings::setShowCurrentLocation( m_currentLocationAction->isChecked() );
 
-    MarbleSettings::setStillQuality( m_controlView->marbleWidget()->mapQuality( Marble::Still ) );
+    MarbleSettings::setStillQuality( m_controlView->marbleWidget()->mapQuality( Still ) );
     MarbleSettings::setAnimationQuality( m_controlView->marbleWidget()->
-                                         mapQuality( Marble::Animation ) );
+                                         mapQuality( Animation ) );
 
     // FIXME: Hopefully Qt will have a getter for this one in the future ...
-    Marble::GraphicsSystem graphicsSystem = (Marble::GraphicsSystem) MarbleSettings::graphicsSystem();
+    GraphicsSystem graphicsSystem = (GraphicsSystem) MarbleSettings::graphicsSystem();
     MarbleSettings::setGraphicsSystem( graphicsSystem );
 
 
@@ -504,14 +565,16 @@ void MarblePart::writeSettings()
                                                volatileTileCacheLimit() / 1024 );
     MarbleSettings::setPersistentTileCacheLimit( m_controlView->marbleWidget()->
                                                  persistentTileCacheLimit() / 1024 );
-
+    
+    // Plugins
     QList<int>   pluginEnabled;
     QList<int>   pluginVisible;
     QStringList  pluginNameId;
 
     QList<RenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
 	pluginEnabled << static_cast<int>( (*i)->enabled() );
         pluginVisible << static_cast<int>( (*i)->visible() );
 	pluginNameId  << (*i)->nameId();
@@ -537,10 +600,20 @@ void MarblePart::writeStatusBarSettings()
 
 void MarblePart::setupActions()
 {
+    // Action: Download Region
+    m_downloadRegionAction = new KAction( this );
+    m_downloadRegionAction->setText( i18nc( "Action for downloading an entire region of a map",
+                                            "Download Region..." ));
+    actionCollection()->addAction( "file_download_region", m_downloadRegionAction );
+    connect( m_downloadRegionAction, SIGNAL( triggered() ), SLOT( showDownloadRegionDialog() ));
+
     // Action: Print Map
     m_printMapAction = KStandardAction::print( this, SLOT( printMapScreenShot() ),
                                                actionCollection() );
 
+    m_printPreviewAction = KStandardAction::printPreview( this, SLOT( printPreview() ),
+                                               actionCollection() );
+                                               
     // Action: Export Map
     m_exportMapAction = new KAction( this );
     actionCollection()->addAction( "exportMap", m_exportMapAction );
@@ -594,11 +667,11 @@ void MarblePart::setupActions()
 			   actionCollection() );
 
     // Action: Get hot new stuff
-    m_newStuffAction = KNS::standardAction( i18nc( "Action for downloading maps (GHNS)",
-                                                   "Download Maps..."),
-                                            this,
-                                            SLOT( showNewStuffDialog() ),
-                                            actionCollection(), "new_stuff" );
+    m_newStuffAction = KNS3::standardAction( i18nc( "Action for downloading maps (GHNS)",
+                                                    "Download Maps..."),
+                                             this,
+                                             SLOT( showNewStuffDialog() ),
+                                             actionCollection(), "new_stuff" );
     m_newStuffAction->setStatusTip( i18nc( "Status tip", "Download new maps"));
     m_newStuffAction->setShortcut( Qt::CTRL + Qt::Key_N );
 
@@ -632,7 +705,8 @@ void MarblePart::setupActions()
     // Action: Show Crosshairs option
     QList<RenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         if ( (*i)->nameId() == "crosshairs" ) {
             actionCollection()->addAction( "show_crosshairs", (*i)->action() );
         }
@@ -655,6 +729,8 @@ void MarblePart::setupActions()
     connect( m_controlSunAction, SIGNAL( triggered( bool ) ),
 	     this,               SLOT( controlSun() ) );
 
+    KStandardAction::redisplay( this, SLOT( reload() ), actionCollection() );
+
     // Action: Lock float items
     m_lockFloatItemsAct = new KAction ( this );
     actionCollection()->addAction( "options_lock_floatitems",
@@ -668,6 +744,14 @@ void MarblePart::setupActions()
 
     KStandardAction::preferences( this, SLOT( editSettings() ),
 				  actionCollection() );
+
+    //    FIXME: Discuss if this is the best place to put this
+    QList<RenderPlugin *>::const_iterator it = pluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const itEnd = pluginList.constEnd();
+    for (; it != itEnd; ++it ) {
+        connect( (*it), SIGNAL( actionGroupsChanged() ),
+                 this, SLOT( createPluginMenus() ) );
+    }
 }
 
 void MarblePart::createInfoBoxesMenu()
@@ -677,7 +761,8 @@ void MarblePart::createInfoBoxesMenu()
     QList<QAction*> actionList;
 
     QList<AbstractFloatItem *>::const_iterator i = floatItemList.constBegin();
-    for (; i != floatItemList.constEnd(); ++i) {
+    QList<AbstractFloatItem *>::const_iterator const end = floatItemList.constEnd();
+    for (; i != end; ++i ) {
         actionList.append( (*i)->action() );
     }
 
@@ -685,14 +770,15 @@ void MarblePart::createInfoBoxesMenu()
     plugActionList( "infobox_actionlist", actionList );
 }
 
-void MarblePart::createOnlineServicesMenu() {
+void MarblePart::createOnlineServicesMenu()
+{
     QList<RenderPlugin *> renderPluginList = m_controlView->marbleWidget()->renderPlugins();
     
     QList<QAction*> actionList;
     
-    QList<RenderPlugin *>::const_iterator i;
-    
-    for( i = renderPluginList.constBegin(); i != renderPluginList.constEnd(); ++i ) {
+    QList<RenderPlugin *>::const_iterator i = renderPluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const end = renderPluginList.constEnd();
+    for (; i != end; ++i ) {
         // FIXME: This will go into the layer manager when AbstractDataPlugin is an interface
         AbstractDataPlugin *dataPlugin = qobject_cast<AbstractDataPlugin *>(*i);
         
@@ -718,10 +804,13 @@ void MarblePart::showDistance( const QString& distance )
     updateStatusBar();
 }
 
-void MarblePart::showZoomLevel( int zoomLevel )
+void MarblePart::showZoomLevel( const int tileLevel )
 {
-    Q_UNUSED( zoomLevel );
-    updateTileZoomLevel();
+    if ( tileLevel == -1 )
+        m_tileZoomLevel = NOT_AVAILABLE;
+    else {
+        m_tileZoomLevel.setNum( tileLevel );
+    }
     updateStatusBar();
 }
 
@@ -732,6 +821,28 @@ void MarblePart::mapThemeChanged( const QString& newMapTheme )
     updateStatusBar();
 }
 
+void MarblePart::createPluginMenus()
+{
+    unplugActionList("plugins_actionlist");
+    QList<QActionGroup*> *tmp_toolbarActionGroups;
+    QList<RenderPlugin *> renderPluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<RenderPlugin *>::const_iterator i = renderPluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const end = renderPluginList.constEnd();
+
+    //Load the toolbars
+    for (; i != end; ++i ) {
+        tmp_toolbarActionGroups = (*i)->toolbarActionGroups();
+
+        if ( tmp_toolbarActionGroups ) {
+
+            foreach( QActionGroup* ag, *tmp_toolbarActionGroups ) {
+                plugActionList( "plugins_actionlist", ag->actions() );
+            }
+        }
+    }
+
+}
+
 void MarblePart::updateTileZoomLevel()
 {
     const int tileZoomLevel =
@@ -739,9 +850,7 @@ void MarblePart::updateTileZoomLevel()
     if ( tileZoomLevel == -1 )
         m_tileZoomLevel = NOT_AVAILABLE;
     else {
-        QString s;
-        s.setNum( tileZoomLevel );
-        m_tileZoomLevel = s;
+        m_tileZoomLevel.setNum( tileZoomLevel );
     }
 }
 
@@ -770,16 +879,15 @@ void MarblePart::setupStatusBar()
         QString( "%1 00.000,0 mu" ).arg(DISTANCE_STRING);
     m_distanceLabel = setupStatusBarLabel( templateDistanceString );
 
-    const QString templateTileZoomLevelString =
-        QString( "%1" ).arg( TILEZOOMLEVEL_STRING );
+    const QString templateTileZoomLevelString = i18n( TILEZOOMLEVEL_STRING );
     m_tileZoomLevelLabel = setupStatusBarLabel( templateTileZoomLevelString );
 
     connect( m_controlView->marbleWidget(), SIGNAL( mouseMoveGeoPosition( QString ) ),
              this,                          SLOT( showPosition( QString ) ) );
     connect( m_controlView->marbleWidget(), SIGNAL( distanceChanged( QString ) ),
              this,                          SLOT( showDistance( QString ) ) );
-    connect( m_controlView->marbleWidget(), SIGNAL( zoomChanged( int ) ),
-             this,                          SLOT( showZoomLevel( int ) ) );
+    connect( m_controlView->marbleWidget()->model(), SIGNAL( tileLevelChanged( int )),
+             SLOT( showZoomLevel( int )));
     connect( m_controlView->marbleWidget()->model(), SIGNAL( themeChanged( QString )),
              this, SLOT( mapThemeChanged( QString )), Qt::QueuedConnection );
 
@@ -814,8 +922,7 @@ void MarblePart::setupDownloadProgressBar()
 
     HttpDownloadManager * const downloadManager =
         m_controlView->marbleWidget()->map()->model()->downloadManager();
-    kDebug() << "got download manager:" << downloadManager;
-
+    Q_ASSERT( downloadManager );
     connect( downloadManager, SIGNAL( jobAdded() ), SLOT( downloadJobAdded() ) );
     connect( downloadManager, SIGNAL( jobRemoved() ), SLOT( downloadJobRemoved() ) );
 }
@@ -855,15 +962,65 @@ void MarblePart::showNewStuffDialog()
                                                       "marble/marble.knsrc" );
     kDebug() << "KNS config file:" << newStuffConfig;
 
-    KNS::Engine  engine;
-    bool         ret = engine.init( newStuffConfig );
-    if ( ret ) {
-        KNS::Entry::List entries = engine.downloadDialogModal(0);
-    }
+    QPointer<KNS3::DownloadDialog> dialog(new KNS3::DownloadDialog(newStuffConfig));
+    dialog->exec();
+    delete dialog;
+}
 
-    // Update the map theme widget by updating the model.
-    // Shouldn't be needed anymore ...
-    //m_controlView->marbleControl()->updateMapThemes();
+// connect to expensive slots, only needed when the non modal dialog is show
+void MarblePart::connectDownloadRegionDialog()
+{
+    connect( m_controlView->marbleWidget(), SIGNAL( visibleLatLonAltBoxChanged( GeoDataLatLonAltBox )),
+             m_downloadRegionDialog, SLOT( setVisibleLatLonAltBox( GeoDataLatLonAltBox )));
+    connect( m_controlView->marbleWidget(), SIGNAL( themeChanged( QString )),
+             m_downloadRegionDialog, SLOT( updateTextureLayer() ));
+}
+
+// disconnect from expensive slots, not needed when dialog is hidden
+void MarblePart::disconnectDownloadRegionDialog()
+{
+    disconnect( m_controlView->marbleWidget(), SIGNAL( visibleLatLonAltBoxChanged( GeoDataLatLonAltBox )),
+                m_downloadRegionDialog, SLOT( setVisibleLatLonAltBox( GeoDataLatLonAltBox )));
+    disconnect( m_controlView->marbleWidget(), SIGNAL( themeChanged( QString )),
+                m_downloadRegionDialog, SLOT( updateTextureLayer() ));
+}
+
+void MarblePart::showDownloadRegionDialog()
+{
+    MarbleModel * const model = m_controlView->marbleWidget()->map()->model();
+    if ( !m_downloadRegionDialog ) {
+        m_downloadRegionDialog = new DownloadRegionDialog( model, widget() );
+        // it might be tempting to move the connects to DownloadRegionDialog's "accepted" and
+        // "applied" signals, be aware that the "hidden" signal might be come before the "accepted"
+        // signal, leading to a too early disconnect.
+        connect( m_downloadRegionDialog, SIGNAL( accepted() ), SLOT( downloadRegion() ));
+        connect( m_downloadRegionDialog, SIGNAL( applied() ), SLOT( downloadRegion() ));
+        connect( m_downloadRegionDialog, SIGNAL( shown() ), SLOT( connectDownloadRegionDialog() ));
+        connect( m_downloadRegionDialog, SIGNAL( hidden() ),
+                 SLOT( disconnectDownloadRegionDialog() ));
+    }
+    // FIXME: get allowed range from current map theme
+    m_downloadRegionDialog->setAllowedTileLevelRange( 0, 18 );
+    m_downloadRegionDialog->setSelectionMethod( DownloadRegionDialog::VisibleRegionMethod );
+    ViewportParams const * const viewport =
+        m_controlView->marbleWidget()->map()->viewParams()->viewport();
+    m_downloadRegionDialog->setSpecifiedLatLonAltBox( viewport->viewLatLonAltBox() );
+    m_downloadRegionDialog->setVisibleLatLonAltBox( viewport->viewLatLonAltBox() );
+    m_downloadRegionDialog->setVisibleTileLevel( model->tileZoomLevel() );
+
+    m_downloadRegionDialog->show();
+    m_downloadRegionDialog->raise();
+    m_downloadRegionDialog->activateWindow();
+}
+
+void MarblePart::downloadRegion()
+{
+    Q_ASSERT( m_downloadRegionDialog );
+    QString const mapThemeId = m_controlView->marbleWidget()->mapThemeId();
+    QString const sourceDir = mapThemeId.left( mapThemeId.lastIndexOf( '/' ));
+    kDebug() << "downloadRegion mapThemeId:" << mapThemeId << sourceDir;
+    TileCoordsPyramid const pyramid = m_downloadRegionDialog->region();
+    m_controlView->marbleWidget()->map()->model()->downloadRegion( sourceDir, pyramid );
 }
 
 void MarblePart::showStatusBarContextMenu( const QPoint& pos )
@@ -898,7 +1055,7 @@ void MarblePart::editSettings()
 
     // It's experimental -- so we remove it for now.
     // FIXME: Delete the following  line once OpenGL support is officially supported.
-    ui_viewSettings.kcfg_graphicsSystem->removeItem( Marble::OpenGLGraphics );
+    ui_viewSettings.kcfg_graphicsSystem->removeItem( OpenGLGraphics );
 
     QString nativeString ( i18n("Native") );
 
@@ -909,7 +1066,7 @@ void MarblePart::editSettings()
     nativeString = i18n( "Native (Mac OS X Core Graphics)" );
     #endif
 
-    ui_viewSettings.kcfg_graphicsSystem->setItemText( Marble::NativeGraphics, nativeString );
+    ui_viewSettings.kcfg_graphicsSystem->setItemText( NativeGraphics, nativeString );
 
     // navigation page
     Ui_MarbleNavigationSettingsWidget  ui_navigationSettings;
@@ -936,7 +1093,8 @@ void MarblePart::editSettings()
 
     QList<RenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
 	parentItem->appendRow( (*i)->item() );
     }
 
@@ -945,64 +1103,73 @@ void MarblePart::editSettings()
     w_pluginSettings->setObjectName( "plugin_page" );
     m_configDialog->addPage( w_pluginSettings, i18n( "Plugins" ),
 			     "preferences-plugin" );
+    // Setting the icons of the pluginSettings page.
+    w_pluginSettings->setConfigIcon( KIcon( "configure" ) );
+    w_pluginSettings->setAboutIcon( KIcon( "help-about" ) );
 
     connect( w_pluginSettings, SIGNAL( pluginListViewClicked() ),
-	                       SLOT( slotEnableButtonApply() ) );
+                               SLOT( enableApplyButton() ) );
     connect( m_configDialog,   SIGNAL( settingsChanged( const QString &) ),
-	                       SLOT( slotUpdateSettings() ) );
+	                       SLOT( updateSettings() ) );
     connect( m_configDialog,   SIGNAL( applyClicked() ),
-	                       SLOT( slotApply() ) );
+	                       SLOT( applyPluginState() ) );
     connect( m_configDialog,   SIGNAL( okClicked() ),
-	                       SLOT( slotApply() ) );
+	                       SLOT( applyPluginState() ) );
     connect( m_configDialog,   SIGNAL( cancelClicked() ),
-	                       SLOT( slotCancel() ) );
+	                       SLOT( retrievePluginState() ) );
+    connect( w_pluginSettings, SIGNAL( aboutPluginClicked( QString ) ),
+                               SLOT( showPluginAboutDialog( QString ) ) );
+    connect( w_pluginSettings, SIGNAL( configPluginClicked( QString ) ),
+                               SLOT( showPluginConfigDialog( QString ) ) );
 
     m_configDialog->show();
 }
 
-void MarblePart::slotEnableButtonApply()
+void MarblePart::enableApplyButton()
 {
-        m_configDialog->enableButtonApply( true );
+    m_configDialog->enableButtonApply( true );
 }
 
-void MarblePart::slotApply()
+void MarblePart::applyPluginState()
 {
     QList<RenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         (*i)->applyItemState();
     }
 }
 
-void MarblePart::slotCancel()
+void MarblePart::retrievePluginState()
 {
     QList<RenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         (*i)->retrieveItemState();
     }
 }
 
-void MarblePart::slotUpdateSettings()
+void MarblePart::updateSettings()
 {
-    qDebug() << "Updating Settings ...";
+    kDebug() << "Updating Settings ...";
 
     // FIXME: Font doesn't get updated instantly.
     m_controlView->marbleWidget()->setDefaultFont( MarbleSettings::mapFont() );
 
     m_controlView->marbleWidget()->
-        setMapQuality( (Marble::MapQuality) MarbleSettings::stillQuality(),
-                       Marble::Still );
+        setMapQuality( (MapQuality) MarbleSettings::stillQuality(),
+                       Still );
     m_controlView->marbleWidget()->
-        setMapQuality( (Marble::MapQuality) MarbleSettings::animationQuality(),
-                       Marble::Animation );
+        setMapQuality( (MapQuality) MarbleSettings::animationQuality(),
+                       Animation );
 
-    Marble::GraphicsSystem graphicsSystem = (Marble::GraphicsSystem) MarbleSettings::graphicsSystem();
+    GraphicsSystem graphicsSystem = (GraphicsSystem) MarbleSettings::graphicsSystem();
 
     m_controlView->marbleWidget()->
-        setDefaultAngleUnit( (Marble::AngleUnit) MarbleSettings::angleUnit() );
+        setDefaultAngleUnit( (AngleUnit) MarbleSettings::angleUnit() );
     MarbleGlobal::getInstance()->locale()->
-        setDistanceUnit( (Marble::DistanceUnit) MarbleSettings::distanceUnit() );
+        setDistanceUnit( (DistanceUnit) MarbleSettings::distanceUnit() );
 
     m_distance = m_controlView->marbleWidget()->distanceString();
     updateStatusBar();
@@ -1032,7 +1199,7 @@ void MarblePart::slotUpdateSettings()
             proxy.setType( QNetworkProxy::HttpProxy );
         }
         else {
-            qDebug() << "Unknown proxy type! Using Http Proxy instead.";
+            kDebug() << "Unknown proxy type! Using Http Proxy instead.";
             proxy.setType( QNetworkProxy::HttpProxy );
         }
     }
@@ -1061,12 +1228,81 @@ void MarblePart::slotUpdateSettings()
     m_previousGraphicsSystem = graphicsSystem;
 }
 
+void MarblePart::reload()
+{
+    m_controlView->marbleWidget()->map()->reload();
+}
+
+void MarblePart::showPluginAboutDialog( const QString& nameId )
+{
+    QList<RenderPlugin *> renderItemList = m_controlView->marbleWidget()->renderPlugins();
+
+    foreach ( RenderPlugin *renderItem, renderItemList ) {
+        if( renderItem->nameId() == nameId ) {
+            QDialog *aboutDialog = renderItem->aboutDialog();
+            if ( aboutDialog ) {
+                aboutDialog->show();
+            }
+        }
+    }
+}
+
+void MarblePart::showPluginConfigDialog( const QString& nameId )
+{
+    QList<RenderPlugin *> renderItemList = m_controlView->marbleWidget()->renderPlugins();
+
+    foreach ( RenderPlugin *renderItem, renderItemList ) {
+        if( renderItem->nameId() == nameId ) {
+            QDialog *configDialog = renderItem->configDialog();
+            if ( configDialog ) {
+                configDialog->show();
+            }
+        }
+    }
+}
+
+void MarblePart::writePluginSettings()
+{
+    KSharedConfig::Ptr sharedConfig = KSharedConfig::openConfig( KGlobal::mainComponent() );
+
+    foreach( RenderPlugin *plugin, m_controlView->marbleWidget()->renderPlugins() ) {
+        KConfigGroup group = sharedConfig->group( QString( "plugin_" ) + plugin->nameId() );
+
+        QHash<QString,QVariant> hash = plugin->settings();
+
+        QHash<QString,QVariant>::iterator it = hash.begin();
+        while( it != hash.end() ) {
+            group.writeEntry( it.key(), it.value() );
+            ++it;
+        }
+        group.sync();
+    }
+}
+
+void MarblePart::readPluginSettings()
+{
+    KSharedConfig::Ptr sharedConfig = KSharedConfig::openConfig( KGlobal::mainComponent() );
+
+    foreach( RenderPlugin *plugin, m_controlView->marbleWidget()->renderPlugins() ) {
+        KConfigGroup group = sharedConfig->group( QString( "plugin_" ) + plugin->nameId() );
+
+        QHash<QString,QVariant> hash = plugin->settings();
+
+        foreach ( const QString& key, group.keyList() ) {
+            hash.insert( key, group.readEntry( key ) );
+        }
+
+        plugin->setSettings( hash );
+    }
+}
+
 void MarblePart::lockFloatItemPosition( bool enabled )
 {
     QList<AbstractFloatItem *> floatItemList = m_controlView->marbleWidget()->floatItems();
 
     QList<AbstractFloatItem *>::const_iterator i = floatItemList.constBegin();
-    for (; i != floatItemList.constEnd(); ++i) {
+    QList<AbstractFloatItem *>::const_iterator const end = floatItemList.constEnd();
+    for (; i != end; ++i ) {
         // Locking one would suffice as it affects all. 
 	// Nevertheless go through all.
         (*i)->setPositionLocked(enabled);
@@ -1084,7 +1320,7 @@ void MarblePart::downloadJobAdded()
         m_downloadProgressBar->setMaximum( m_downloadProgressBar->maximum() + 1 );
     }
 
-//     qDebug() << "downloadProgressJobAdded: value/maximum: "
+//     kDebug() << "downloadProgressJobAdded: value/maximum: "
 //              << m_downloadProgressBar->value() << '/' << m_downloadProgressBar->maximum();
 
     m_downloadProgressBar->setUpdatesEnabled( true );
@@ -1099,7 +1335,7 @@ void MarblePart::downloadJobRemoved()
         m_downloadProgressBar->setVisible( false );
     }
 
-//     qDebug() << "downloadProgressJobCompleted: value/maximum: "
+//     kDebug() << "downloadProgressJobCompleted: value/maximum: "
 //              << m_downloadProgressBar->value() << '/' << m_downloadProgressBar->maximum();
 
     m_downloadProgressBar->setUpdatesEnabled( true );
